<?php
/**
 * Accelerate Theme Customizer
 *
 * @package ThemeGrill
 * @subpackage Accelerate
 * @since Accelerate 1.0.7
 */

function accelerate_customize_register($wp_customize) {

	// Theme important links started
	class Accelerate_Important_Links extends WP_Customize_Control {

		public $type = "accelerate-important-links";

		public function render_content() {
			//Add Theme instruction, Support Forum, Demo Link, Rating Link
			$important_links = array(
				'support' => array(
					'link' => esc_url('https://themegrill.com/support-forum/'),
					'text' => __('Support Forum', 'accelerate'),
				),
				'documentation' => array(
					'link' => esc_url('https://themegrill.com/theme-instruction/accelerate-pro/'),
					'text' => __('Documentation', 'accelerate'),
				),
				'demo' => array(
					'link' => esc_url('https://demo.themegrill.com/accelerate-pro/'),
					'text' => __('View Demo', 'accelerate'),
				),
			);
			foreach ($important_links as $important_link) {
				echo '<p><a target="_blank" href="' . $important_link['link'] . '" >' . esc_attr($important_link['text']) . ' </a></p>';
			}
		}

	}

	$wp_customize->add_section('accelerate_important_links', array(
		'priority' => 700,
		'title' => __('Accelerate Pro', 'accelerate'),
	));

	/**
	 * This setting has the dummy Sanitization function as it contains no value to be sanitized
	 */
	$wp_customize->add_setting('accelerate_important_links', array(
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'accelerate_links_sanitize'
	));

	$wp_customize->add_control(new Accelerate_Important_Links($wp_customize, 'important_links', array(
		'section' => 'accelerate_important_links',
		'settings' => 'accelerate_important_links'
	)));
	// Theme Important Links Ended

	// Start of the Header Options
	// Header Options Area
	$wp_customize->add_panel('accelerate_header_options', array(
		'capabitity' => 'edit_theme_options',
		'priority' => 500,
		'title' => __('Header', 'accelerate')
	));

	if ( ! function_exists( 'the_custom_logo' ) ) {
		// Header Logo upload option
		$wp_customize->add_section('accelerate_header_logo', array(
			'priority' => 1,
			'title' => __('Header Logo', 'accelerate'),
			'panel' => 'accelerate_header_options'
		));

		$wp_customize->add_setting('accelerate[accelerate_header_logo_image]', array(
			'default' => '',
			'type' => 'option',
			'capability' => 'edit_theme_options',
			'sanitize_callback' => 'esc_url_raw'
		));

		$wp_customize->add_control(new WP_Customize_Image_Control($wp_customize, 'accelerate[accelerate_header_logo_image]', array(
			'label' => __('Upload logo for your header.', 'accelerate'),
			'section' => 'accelerate_header_logo',
			'setting' => 'accelerate[accelerate_header_logo_image]'
		)));
	}

	// Header logo and text display type option
	$wp_customize->add_section('accelerate_show_option', array(
		'priority' => 2,
		'title' => __('Show', 'accelerate'),
		'panel' => 'accelerate_header_options'
	));

	$wp_customize->add_setting('accelerate[accelerate_show_header_logo_text]', array(
		'default' => 'text_only',
		'type' => 'option',
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'accelerate_radio_select_sanitize'
	));

	$wp_customize->add_control('accelerate[accelerate_show_header_logo_text]', array(
		'type' => 'radio',
		'label' => __('Choose the option that you want.', 'accelerate'),
		'section' => 'accelerate_show_option',
		'choices' => array(
			'logo_only' => __('Header Logo Only', 'accelerate'),
			'text_only' => __('Header Text Only', 'accelerate'),
			'both' => __('Show Both', 'accelerate'),
			'none' => __('Disable', 'accelerate')
		)
	));

	// Header display type option
	$wp_customize->add_section('accelerate_header_display_type_option', array(
		'priority' => 2,
		'title' => __('Header Display Type', 'accelerate'),
		'panel' => 'accelerate_header_options'
	));

	$wp_customize->add_setting('accelerate[accelerate_header_display_type]', array(
		'default' => 'one',
		'type' => 'option',
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'accelerate_radio_select_sanitize'
	));

	$wp_customize->add_control('accelerate[accelerate_header_display_type]', array(
		'type' => 'radio',
		'label' => __('Choose the header display type that you want.', 'accelerate'),
		'section' => 'accelerate_header_display_type_option',
		'choices' => array(
			'one' => __( 'Type 1 (Default): Header text & logo on left, header sidebar on right', 'accelerate' ),
			'two' => __( 'Type 2: Header sidebar on left, header text & logo on right', 'accelerate' ),
			'three' => __( 'Type 3: Header text, header sidebar both aligned center', 'accelerate' )
		)
	));

	// Menu display type option
	$wp_customize->add_section('accelerate_menu_display_type_option', array(
		'priority' => 2,
		'title' => __('Menu Display Type', 'accelerate'),
		'panel' => 'accelerate_header_options'
	));

	$wp_customize->add_setting('accelerate[accelerate_menu_display_type]', array(
		'default' => 'one',
		'type' => 'option',
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'accelerate_radio_select_sanitize'
	));

	$wp_customize->add_control('accelerate[accelerate_menu_display_type]', array(
		'type' => 'radio',
		'label' => __('Choose the menu display type that you want.', 'accelerate'),
		'section' => 'accelerate_menu_display_type_option',
		'choices' => array(
			'one' => __( 'Type 1 (Default): Menu aligned left', 'accelerate' ),
			'two' => __( 'Type 2: Menu aligned center', 'accelerate' ),
			'three' => __( 'Type 3: Menu aligned right', 'accelerate' )
		)
	));

	// Menu background cover full width option
	$wp_customize->add_setting('accelerate[accelerate_menu_background_cover_full_width_option]', array(
		'default' => 0,
		'type' => 'option',
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'accelerate_checkbox_sanitize'
	));

	$wp_customize->add_control('accelerate[accelerate_menu_background_cover_full_width_option]', array(
		'type' => 'checkbox',
		'label' => __('Check to make the menu background cover the full width of its container', 'accelerate'),
		'section' => 'accelerate_menu_display_type_option',
		'settings' => 'accelerate[accelerate_menu_background_cover_full_width_option]'
	));

	// Header Top bar activate option
	$wp_customize->add_section('accelerate_activate_top_header_bar_option', array(
		'priority' => 2,
		'title' => __('Activate Header Top Bar', 'accelerate'),
		'panel' => 'accelerate_header_options'
	));

	$wp_customize->add_setting('accelerate[accelerate_activate_top_header_bar]', array(
		'default' => 0,
		'type' => 'option',
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'accelerate_checkbox_sanitize'
	));

	$wp_customize->add_control('accelerate[accelerate_activate_top_header_bar]', array(
		'type' => 'checkbox',
		'label' => __('Check to show top header bar. The top header bar includes social icons and menu area.', 'accelerate'),
		'section' => 'accelerate_activate_top_header_bar_option',
		'settings' => 'accelerate[accelerate_activate_top_header_bar]'
	));

	// Header top bar display type option
	$wp_customize->add_section('accelerate_hedaer_top_bar_display_type_option', array(
		'priority' => 2,
		'title' => __('Header Top Bar Display Type', 'accelerate'),
		'panel' => 'accelerate_header_options'
	));

	$wp_customize->add_setting('accelerate[accelerate_top_bar_display_type]', array(
		'default' => 'one',
		'type' => 'option',
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'accelerate_radio_select_sanitize'
	));

	$wp_customize->add_control('accelerate[accelerate_top_bar_display_type]', array(
		'type' => 'radio',
		'label' => __('Choose top bar display type.', 'accelerate'),
		'section' => 'accelerate_hedaer_top_bar_display_type_option',
		'choices' => array(
			'one' => __( 'Type 1 (Default): Social icons on left and top menu area on right', 'accelerate' ),
			'two' => __( 'Type 2: Top menu on left and social icons on right', 'accelerate' )
		)
	));

	// Header image position option
	$wp_customize->add_section('accelerate_header_image_position_section', array(
		'priority' => 3,
		'title' => __('Header Image Position', 'accelerate'),
		'panel' => 'accelerate_header_options'
	));

	$wp_customize->add_setting('accelerate[accelerate_header_image_position]', array(
		'default' => 'position_two',
		'type' => 'option',
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'accelerate_radio_select_sanitize'
	));

	$wp_customize->add_control('accelerate[accelerate_header_image_position]', array(
		'type' => 'radio',
		'label' => __('Choose top header image display position.','accelerate'),
		'section' => 'accelerate_header_image_position_section',
		'choices' => array(
			'position_one' => __( 'Position One: Display the Header image just above the site title/text.', 'accelerate' ),
			'position_two' => __( 'Position Two (Default): Display the Header image between site title/text and the main/primary menu.', 'accelerate' ),
			'position_three' => __( 'Position Three: Display the Header image below main/primary menu.', 'accelerate' )
		)
	));

	// New Responsive Menu
	$wp_customize->add_section('accelerate_new_menu', array(
		'priority' => 4,
		'title'    => esc_html__('Responsive Menu Style', 'accelerate'),
		'panel'    => 'accelerate_header_options'
	));

	$wp_customize->add_setting('accelerate[accelerate_new_menu]', array(
		'default'           => '',
		'type'              => 'option',
		'capability'        => 'edit_theme_options',
		'sanitize_callback' => 'accelerate_checkbox_sanitize'
	));

	$wp_customize->add_control('accelerate[accelerate_new_menu]', array(
		'type'    => 'checkbox',
		'label'   => esc_html__('Switch to new responsive menu.', 'accelerate'),
		'section' => 'accelerate_new_menu'
	));

	// make header image as link option
	$wp_customize->add_setting('accelerate[accelerate_header_image_link]', array(
		'default' => 0,
		'type' => 'option',
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'accelerate_checkbox_sanitize'
	));

	$wp_customize->add_control('accelerate[accelerate_header_image_link]', array(
		'type' => 'checkbox',
		'label' => __('Check to make header image link back to home page.', 'accelerate'),
		'section' => 'accelerate_header_image_position_section',
		'settings' => 'accelerate[accelerate_header_image_link]'
	));
	// End of Header Options

	// Start of the Design Options
	$wp_customize->add_panel('accelerate_design_options', array(
		'capabitity' => 'edit_theme_options',
		'priority' => 505,
		'title' => __('Design', 'accelerate')
	));

	// site layout setting
	$wp_customize->add_section('accelerate_site_layout_setting', array(
		'priority' => 1,
		'title' => __('Site Layout', 'accelerate'),
		'panel' => 'accelerate_design_options'
	));

	$wp_customize->add_setting('accelerate[accelerate_site_layout]', array(
		'default' => 'wide',
		'type' => 'option',
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'accelerate_radio_select_sanitize'
	));

	$wp_customize->add_control('accelerate[accelerate_site_layout]', array(
		'type' => 'radio',
		'label' => __('Choose your site layout. The change is reflected in whole site.', 'accelerate'),
		'choices' => array(
			'box' => __( 'Boxed layout', 'accelerate' ),
			'wide' => __( 'Wide layout', 'accelerate' )
		),
		'section' => 'accelerate_site_layout_setting'
	));

	class Accelerate_Image_Radio_Control extends WP_Customize_Control {

		public function render_content() {

			if ( empty( $this->choices ) )
				return;

			$name = '_customize-radio-' . $this->id;

			?>
			<style>
				#accelerate-img-container .accelerate-radio-img-img {
					border: 3px solid #DEDEDE;
					margin: 0 5px 5px 0;
					cursor: pointer;
					border-radius: 3px;
					-moz-border-radius: 3px;
					-webkit-border-radius: 3px;
				}
				#accelerate-img-container .accelerate-radio-img-selected {
					border: 3px solid #AAA;
					border-radius: 3px;
					-moz-border-radius: 3px;
					-webkit-border-radius: 3px;
				}
				input[type=checkbox]:before {
					content: '';
					margin: -3px 0 0 -4px;
				}
			</style>
			<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
			<ul class="controls" id='accelerate-img-container'>
			<?php
				foreach ( $this->choices as $value => $label ) :
					$class = ($this->value() == $value)?'accelerate-radio-img-selected accelerate-radio-img-img':'accelerate-radio-img-img';
					?>
					<li style="display: inline;">
					<label>
						<input <?php $this->link(); ?>style='display:none' type="radio" value="<?php echo esc_attr( $value ); ?>" name="<?php echo esc_attr( $name ); ?>" <?php $this->link(); checked( $this->value(), $value ); ?> />
						<img src = '<?php echo esc_html( $label ); ?>' class = '<?php echo $class; ?>' />
					</label>
					</li>
					<?php
				endforeach;
			?>
			</ul>
			<script type="text/javascript">
				jQuery(document).ready(function($) {
					$('.controls#accelerate-img-container li img').click(function(){
						$('.controls#accelerate-img-container li').each(function(){
							$(this).find('img').removeClass ('accelerate-radio-img-selected') ;
						});
						$(this).addClass ('accelerate-radio-img-selected') ;
					});
				});
			</script>
			<?php
		}
	}

	// default layout setting
	$wp_customize->add_section('accelerate_default_layout_setting', array(
		'priority' => 2,
		'title' => __('Default layout', 'accelerate'),
		'panel'=> 'accelerate_design_options'
	));

	$wp_customize->add_setting('accelerate[accelerate_default_layout]', array(
		'default' => 'right_sidebar',
		'type' => 'option',
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'accelerate_radio_select_sanitize'
	));

	$wp_customize->add_control(new Accelerate_Image_Radio_Control($wp_customize, 'accelerate[accelerate_default_layout]', array(
		'type' => 'radio',
		'label' => __('Select default layout. This layout will be reflected in whole site archives, search etc. The layout for a single post and page can be controlled from below options.', 'accelerate'),
		'section' => 'accelerate_default_layout_setting',
		'settings' => 'accelerate[accelerate_default_layout]',
		'choices' => array(
			'right_sidebar' => ACCELERATE_ADMIN_IMAGES_URL . '/right-sidebar.png',
			'left_sidebar' => ACCELERATE_ADMIN_IMAGES_URL . '/left-sidebar.png',
			'no_sidebar_full_width' => ACCELERATE_ADMIN_IMAGES_URL . '/no-sidebar-full-width-layout.png',
			'no_sidebar_content_centered' => ACCELERATE_ADMIN_IMAGES_URL . '/no-sidebar-content-centered-layout.png'
		)
	)));

	// default layout for pages
	$wp_customize->add_section('accelerate_default_page_layout_setting', array(
		'priority' => 3,
		'title' => __('Default layout for pages only', 'accelerate'),
		'panel'=> 'accelerate_design_options'
	));

	$wp_customize->add_setting('accelerate[accelerate_pages_default_layout]', array(
		'default' => 'right_sidebar',
		'type' => 'option',
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'accelerate_radio_select_sanitize'
	));

	$wp_customize->add_control(new Accelerate_Image_Radio_Control($wp_customize, 'accelerate[accelerate_pages_default_layout]', array(
		'type' => 'radio',
		'label' => __('Select default layout for pages. This layout will be reflected in all pages unless unique layout is set for specific page.', 'accelerate'),
		'section' => 'accelerate_default_page_layout_setting',
		'settings' => 'accelerate[accelerate_pages_default_layout]',
		'choices' => array(
			'right_sidebar' => ACCELERATE_ADMIN_IMAGES_URL . '/right-sidebar.png',
			'left_sidebar' => ACCELERATE_ADMIN_IMAGES_URL . '/left-sidebar.png',
			'no_sidebar_full_width' => ACCELERATE_ADMIN_IMAGES_URL . '/no-sidebar-full-width-layout.png',
			'no_sidebar_content_centered' => ACCELERATE_ADMIN_IMAGES_URL . '/no-sidebar-content-centered-layout.png'
		)
	)));

	// default layout for single posts
	$wp_customize->add_section('accelerate_default_single_posts_layout_setting', array(
		'priority' => 4,
		'title' => __('Default layout for single posts only', 'accelerate'),
		'panel'=> 'accelerate_design_options'
	));

	$wp_customize->add_setting('accelerate[accelerate_single_posts_default_layout]', array(
		'default' => 'right_sidebar',
		'type' => 'option',
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'accelerate_radio_select_sanitize'
	));

	$wp_customize->add_control(new Accelerate_Image_Radio_Control($wp_customize, 'accelerate[accelerate_single_posts_default_layout]', array(
		'type' => 'radio',
		'label' => __('Select default layout for single posts. This layout will be reflected in all single posts unless unique layout is set for specific post.', 'accelerate'),
		'section' => 'accelerate_default_single_posts_layout_setting',
		'settings' => 'accelerate[accelerate_single_posts_default_layout]',
		'choices' => array(
			'right_sidebar' => ACCELERATE_ADMIN_IMAGES_URL . '/right-sidebar.png',
			'left_sidebar' => ACCELERATE_ADMIN_IMAGES_URL . '/left-sidebar.png',
			'no_sidebar_full_width' => ACCELERATE_ADMIN_IMAGES_URL . '/no-sidebar-full-width-layout.png',
			'no_sidebar_content_centered' => ACCELERATE_ADMIN_IMAGES_URL . '/no-sidebar-content-centered-layout.png'
		)
	)));

	// Posts page listing display type setting
	$wp_customize->add_section('accelerate_post_page_display_type_setting', array(
		'priority' => 5,
		'title' => __('Posts page listing display type', 'accelerate'),
		'panel' => 'accelerate_design_options'
	));

	$wp_customize->add_setting('accelerate[accelerate_posts_page_display_type]', array(
		'default' => 'large_image',
		'type' => 'option',
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'accelerate_radio_select_sanitize'
	));

	$wp_customize->add_control('accelerate[accelerate_posts_page_display_type]', array(
		'type' => 'radio',
		'label' => __('Choose the display type for the latests posts view or posts page view (static front page).', 'accelerate'),
		'choices' => array(
			'large_image' => __( 'Large featured image', 'accelerate' ),
			'small_image' => __( 'Small featured image', 'accelerate' ),
			'small_image_alternate' => __( 'Small featured image with alternating sides', 'accelerate' )
		),
		'section' => 'accelerate_post_page_display_type_setting'
	));

	// Archive/category posts listing display type setting
	$wp_customize->add_section('accelerate_archive_category_display_type_setting', array(
		'priority' => 6,
		'title' => __('Archive/Category posts listing display type', 'accelerate'),
		'panel' => 'accelerate_design_options'
	));

	$wp_customize->add_setting('accelerate[accelerate_archive_display_type]', array(
		'default' => 'large_image',
		'type' => 'option',
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'accelerate_radio_select_sanitize'
	));

	$wp_customize->add_control('accelerate[accelerate_archive_display_type]', array(
		'type' => 'radio',
		'label' => __('Choose the display type for the archive/category view.', 'accelerate'),
		'choices' => array(
			'large_image'  => __( 'Large featured image', 'accelerate' ),
			'small_image'  => __( 'Small featured image', 'accelerate' ),
			'small_image_alternate'    => __( 'Small featured image with alternating sides', 'accelerate' )
		),
		'section' => 'accelerate_archive_category_display_type_setting'
	));

	if ( ! function_exists( 'wp_update_custom_css_post' ) ) {
		// Custom CSS setting
		class Accelerate_Custom_CSS_Control extends WP_Customize_Control {

			public $type = 'custom_css';

			public function render_content() {
			?>
				<label>
					<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
					<textarea rows="5" style="width:100%;" <?php $this->link(); ?>><?php echo esc_textarea( $this->value() ); ?></textarea>
				</label>
			<?php
			}

		}

		$wp_customize->add_section('accelerate_custom_css_setting', array(
			'priority' => 7,
			'title' => __('Custom CSS', 'accelerate'),
			'panel' => 'accelerate_design_options'
		));

		$wp_customize->add_setting('accelerate[accelerate_custom_css]', array(
			'default' => '',
			'type' => 'option',
			'capability' => 'edit_theme_options',
			'sanitize_callback' => 'wp_filter_nohtml_kses',
			'sanitize_js_callback' => 'wp_filter_nohtml_kses'
		));

		$wp_customize->add_control(new Accelerate_Custom_CSS_Control($wp_customize, 'accelerate[accelerate_custom_css]', array(
			'label' => __('Write your custom css.', 'accelerate'),
			'section' => 'accelerate_custom_css_setting',
			'settings' => 'accelerate[accelerate_custom_css]'
		)));
	}
	// End of Design Options

	// Start of the Social Links Options
	$wp_customize->add_panel('accelerate_social_links_options', array(
		'capabitity' => 'edit_theme_options',
		'priority' => 510,
		'title' => __('Social Links', 'accelerate')
	));

	// Social links activate option
	$wp_customize->add_section('accelerate_social_links_setting', array(
		'priority' => 1,
		'title' => __('Activate social links area', 'accelerate'),
		'panel' => 'accelerate_social_links_options'
	));

	$wp_customize->add_setting('accelerate[accelerate_activate_social_links]', array(
		'default' => 0,
		'type' => 'option',
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'accelerate_checkbox_sanitize'
	));

	$wp_customize->add_control('accelerate[accelerate_activate_social_links]', array(
		'type' => 'checkbox',
		'label' => __('Check to activate social links area. You also need to activate the header top bar section in Header options to show this social links area', 'accelerate'),
		'section' => 'accelerate_social_links_setting',
		'settings' => 'accelerate[accelerate_activate_social_links]'
	));

	$accelerate_social_links = array(
		'accelerate_social_facebook' => __( 'Facebook', 'accelerate' ),
		'accelerate_social_twitter' => __( 'Twitter', 'accelerate' ),
		'accelerate_social_googleplus' => __( 'GooglePlus' , 'accelerate' ),
		'accelerate_social_instagram' => __( 'Instagram', 'accelerate' ),
		'accelerate_social_codepen' => __( 'CodePen', 'accelerate' ),
		'accelerate_social_digg' => __( 'Digg', 'accelerate' ),
		'accelerate_social_dribbble' => __( 'Dribbble', 'accelerate' ),
		'accelerate_social_flickr' => __( 'Flickr', 'accelerate' ),
		'accelerate_social_github' => __( 'GitHub', 'accelerate' ),
		'accelerate_social_linkedin' => __( 'LinkedIn', 'accelerate' ),
		'accelerate_social_pinterest' => __( 'Pinterest', 'accelerate' ),
		'accelerate_social_reddit' => __( 'Reddit', 'accelerate' ),
		'accelerate_social_skype' => __( 'Skype', 'accelerate' ),
		'accelerate_social_stumbleupon' => __( 'StumbleUpon', 'accelerate' ),
		'accelerate_social_tumblr' => __( 'Tumblr', 'accelerate' ),
		'accelerate_social_vimeo' => __( 'Vimeo', 'accelerate' ),
		'accelerate_social_wordpress' => __( 'WordPress', 'accelerate' ),
		'accelerate_social_youtube' => __( 'YouTube', 'accelerate' ),
		'accelerate_social_xing' => __( 'Xing', 'accelerate' ),
		'accelerate_social_weibo' => __( 'Weibo', 'accelerate' )
	);

	$i = 1;
	foreach ( $accelerate_social_links as $key => $value ) {

		$wp_customize->add_section('accelerate_social_sites_section'.$i, array(
			'priority' => 2,
			'title' => $value,
			'panel' => 'accelerate_social_links_options'
		));

		// adding social sites link
		$wp_customize->add_setting('accelerate['.$key.']', array(
			'default' => '',
			'type' => 'option',
			'capability' => 'edit_theme_options',
			'sanitize_callback' => 'esc_url_raw'
		));

		$wp_customize->add_control('accelerate['.$key.']', array(
			'label' => sprintf( __( 'Add link for %1$s', 'accelerate' ), $value ),
			'section' => 'accelerate_social_sites_section'.$i,
			'setting' => 'accelerate['.$key.']'
		));

		// adding social open in new page tab setting
		$wp_customize->add_setting('accelerate['.$key.'new_tab]', array(
			'default' => 0,
			'type' => 'option',
			'capability' => 'edit_theme_options',
			'sanitize_callback' => 'accelerate_checkbox_sanitize'
		));

		$wp_customize->add_control('accelerate['.$key.'new_tab]', array(
			'type' => 'checkbox',
			'label' => __( 'Check to show in new tab', 'accelerate' ),
			'section' => 'accelerate_social_sites_section'.$i,
			'setting' => 'accelerate['.$key.'new_tab]'
		));

		$i++;

	}

	// Additional Social Icons setting
    class Accelerate_Additional_Social_Icons_Control extends WP_Customize_Control {

      public $type = 'accelerate-additional-social-icons';

      public function render_content() {
         _e( 'Add Font Awesome icon name. Example: whatsapp. You can find list <a href="http://fortawesome.github.io/Font-Awesome/icons/">here</a>', 'accelerate' );
      ?>
         <input type="text" value="<?php echo sanitize_text_field( $this->value() ); ?>" <?php $this->link(); ?>>
      <?php }

    }

	//Array for Additional Icons
	$accelerate_additional_icons = array(
		'accelerate_additional_icon_one' => esc_html__( 'First Additional Social Icon', 'accelerate' ),
		'accelerate_additional_icon_two' => esc_html__( 'Second Additional Social Icon', 'accelerate' ),
		'accelerate_additional_icon_three' => esc_html__( 'Third Additional Social Icon', 'accelerate' ),
		'accelerate_additional_icon_four' => esc_html__( 'Fourth Additional Social Icon', 'accelerate' ),
		'accelerate_additional_icon_five' => esc_html__( 'Fifth Additional Social Icon', 'accelerate' )
	);

	//Start of Additional Social Icons Section
	$wp_customize->add_section('accelerate_additional_icons_section', array(
			'priority' => 3,
			'title' => esc_html__( 'Additional Social Icons', 'accelerate' ),
			'panel' => 'accelerate_social_links_options'
	));

	foreach ($accelerate_additional_icons as $key => $value) {

		// additional social icon link
		$wp_customize->add_setting('accelerate['.$key.'_link]', array(
			'default' => '',
			'type' => 'option',
			'capability' => 'edit_theme_options',
			'sanitize_callback' => 'esc_url_raw'
		));

		$wp_customize->add_control('accelerate['.$key.'_link]', array(
			'label' => sprintf( esc_html__( 'Add link for %1$s', 'accelerate' ), $value ),
			'section' => 'accelerate_additional_icons_section',
			'setting' => 'accelerate['.$key.'_link]'
		));

		// FontAwesome icon class
		$wp_customize->add_setting('accelerate['.$key.'_icon]', array(
			'default' => '',
			'type' => 'option',
			'capability' => 'edit_theme_options',
			'sanitize_callback' => 'wp_filter_nohtml_kses'
		));

		$wp_customize->add_control( new Accelerate_Additional_Social_Icons_Control($wp_customize, 'accelerate['.$key.'_icon]', array(
			'section' => 'accelerate_additional_icons_section',
			'setting' => 'accelerate['.$key.'_icon]'
		)));

		// additional icon color
		$wp_customize->add_setting('accelerate['.$key.'_color]', array(
			'default' => '',
			'type' => 'option',
			'capability' => 'edit_theme_options',
			'sanitize_callback' => 'accelerate_color_option_hex_sanitize',
		    'sanitize_js_callback' => 'accelerate_color_escaping_option_sanitize'
		));

		$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'accelerate['.$key.'_color]', array(
			'label' => sprintf( esc_html__( 'Choose a color for %1$s', 'accelerate' ), $value ),
			'section' => 'accelerate_additional_icons_section',
			'setting' => 'accelerate['.$key.'_color]'
		)));

		//additional icon open in new tab
		$wp_customize->add_setting('accelerate['.$key.'_new_tab]', array(
			'default' => 0,
			'type' => 'option',
			'capability' => 'edit_theme_options',
			'sanitize_callback' => 'accelerate_checkbox_sanitize'
		));

		$wp_customize->add_control('accelerate['.$key.'_new_tab]', array(
			'type' => 'checkbox',
			'label' => esc_html__( 'Check to open in new tab', 'accelerate' ),
			'section' => 'accelerate_additional_icons_section',
			'setting' => 'accelerate['.$key.'_new_tab]'
		));
	}
	// End of Social Links Options

	// Start of the Additional Options
	$wp_customize->add_panel('accelerate_additional_options', array(
		'capabitity' => 'edit_theme_options',
		'priority' => 510,
		'title' => __('Additional', 'accelerate')
	));

	if ( ! function_exists( 'has_site_icon' ) ) {

		 // favicon activate option
		 $wp_customize->add_section('accelerate_additional_activate_section', array(
			'priority' => 1,
			'title' => __('Activate favicon', 'accelerate'),
			'panel' => 'accelerate_additional_options'
		 ));

		 $wp_customize->add_setting('accelerate[accelerate_activate_favicon]', array(
			'default' => 0,
			'type' => 'option',
			'capability' => 'edit_theme_options',
			'sanitize_callback' => 'accelerate_checkbox_sanitize'
		 ));

		 $wp_customize->add_control('accelerate[accelerate_activate_favicon]', array(
		 	'type' => 'checkbox',
			'label' => __('Check to activate favicon. Upload fav icon from below option', 'accelerate'),
			'section' => 'accelerate_additional_activate_section',
			'settings' => 'accelerate[accelerate_activate_favicon]'
		 ));

		 // favicon upload option
		 $wp_customize->add_section('accelerate_favicon_upload_section',array(
			'priority' => 2,
			'title' => __('Upload favicon', 'accelerate'),
			'panel' => 'accelerate_additional_options'
		 ));

		 $wp_customize->add_setting('accelerate[accelerate_favicon]', array(
			'default' => 0,
			'type' => 'option',
			'capability' => 'edit_theme_options',
			'sanitize_callback' => 'esc_url_raw'
		 ));

		 $wp_customize->add_control(new WP_Customize_Image_Control($wp_customize, 'accelerate[accelerate_favicon]', array(
			'label' => __('Upload favicon for your site.', 'accelerate'),
			'section' => 'accelerate_favicon_upload_section',
			'settings' => 'accelerate[accelerate_favicon]'
		 )));
	}

	// excerpt/full post option
	$wp_customize->add_section('accelerate_excerpt_full_post_setting', array(
		'priority' => 3,
		'title' => __('Excerpts or Full Posts option', 'accelerate'),
		'panel' => 'accelerate_additional_options'
	));

	$wp_customize->add_setting('accelerate[accelerate_toggle_excerpt_full_post]', array(
		'default' => 'full_post',
		'type' => 'option',
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'accelerate_radio_select_sanitize'
	));

	$wp_customize->add_control('accelerate[accelerate_toggle_excerpt_full_post]', array(
		'type' => 'radio',
		'label' => __('Toggle between displaying excerpts and full posts on your blog and archives.', 'accelerate'),
		'choices' => array(
			'full_post' => __( 'Show full post content', 'accelerate' ),
			'excerpt'   => __( 'Show excerpt', 'accelerate' )
		),
		'section' => 'accelerate_excerpt_full_post_setting'
	));

	// excerpt length setting
	$wp_customize->add_section('accelerate_excerpt_length_setting', array(
		'priority' => 4,
		'title' => __('Excerpt Length', 'accelerate'),
		'panel' => 'accelerate_additional_options'
	));

	$wp_customize->add_setting('accelerate[accelerate_excerpt_length]', array(
		'default' => 40,
		'type' => 'option',
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'accelerate_excerpt_length_sanitize'
	));

	$wp_customize->add_control('accelerate[accelerate_excerpt_length]', array(
		'label' => __('Enter the number of Words you wish to show on excerpt. Default value is 40 words.', 'accelerate'),
		'setting' => 'accelerate[accelerate_excerpt_length]',
		'section' => 'accelerate_excerpt_length_setting'
	));

	// excerpt text setting
	$wp_customize->add_section('accelerate_excerpt_text_setting', array(
		'priority' => 5,
		'title' => __('Excerpt Read More Text', 'accelerate'),
		'panel' => 'accelerate_additional_options'
	));

	$wp_customize->add_setting('accelerate[accelerate_read_more_text]', array(
		'default' => __('Read more', 'accelerate'),
		'type' => 'option',
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'wp_filter_nohtml_kses'
	));

	$wp_customize->add_control('accelerate[accelerate_read_more_text]', array(
		'label' => __('Replace the default Read more text with your own words', 'accelerate'),
		'setting' => 'accelerate[accelerate_read_more_text]',
		'section' => 'accelerate_excerpt_text_setting'
	));

	class Accelerate_Editor_Custom_Control extends WP_Customize_Control {

		public $type = "accelerate_editor_control";

		public function render_content() {
			?>
			<script type="text/javascript">
				(function ($) {
					wp.customizerCtrlEditor = {
						init: function () {

							$(window).load(function () {

								$('textarea.wp-editor-area').each(function () {
									var tArea = $(this),
										id = tArea.attr('id'),
										name = tArea.attr('name'),
										input = $('input[data-customize-setting-link="' + name + '"]'),
										editor = tinyMCE.get(id),
										setChange,
										content;

									if (editor) {
										editor.on('change', function (e) {
											editor.save();
											content = editor.getContent();
											clearTimeout(setChange);
											setChange = setTimeout(function () {
												input.val(content).trigger('change');
											}, 500);
										});
									}

									tArea.css({
										visibility: 'visible'
									}).on('keyup', function () {
										content = tArea.val();
										clearTimeout(setChange);
										setChange = setTimeout(function () {
											input.val(content).trigger('change');
										}, 500);
									});
								});
							});
						}
					};
					wp.customizerCtrlEditor.init();
				})(jQuery);
			</script>
			<label>
				<span class="customize-control-title"><?php echo esc_html($this->label); ?></span>
				<input type="hidden" <?php $this->link(); ?> value="<?php echo esc_textarea($this->value()); ?>">
			</label>
			<?php
			$settings = array(
				'textarea_name' => $this->id,
				'teeny' => true,
			);
			$new_id = str_replace(array('[', ']'), '', $this->id);
			wp_editor(htmlspecialchars_decode($this->value()), $new_id, $settings);

			do_action('admin_print_footer_scripts');
			?>
			<?php
		}

	}

	// Footer editor option
	$default_footer_value = __( 'Copyright &copy; ', 'accelerate' ).'[the-year] [site-link] '.__( 'Theme by: ', 'accelerate' ).'[tg-link] '.__( 'Powered by: ', 'accelerate' ).'[wp-link]';

	$wp_customize->add_section('accelerate_footer_copyright_section', array(
		'priority' => 6,
		'title' => __( 'Footer Copyright Editor', 'accelerate' ),
		'panel' => 'accelerate_additional_options'
	));

	$wp_customize->add_setting('accelerate[accelerate_footer_editor]', array(
		'default' => $default_footer_value,
		'type' => 'option',
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'accelerate_footer_editor_sanitize'
	));

	$wp_customize->add_control(new Accelerate_Editor_Custom_Control($wp_customize, 'accelerate[accelerate_footer_editor]', array(
		'label' => __( 'Edit the Copyright information in your footer. You can also use shortcodes [the-year], [site-link], [wp-link], [tg-link] for current year, your site link, WordPress site link and ThemeGrill site link respectively.', 'accelerate'  ),
		'section' => 'accelerate_footer_copyright_section',
		'setting' => 'accelerate[accelerate_footer_editor]'
	)));

	// Sticky post and sidebar section
	$wp_customize->add_section( 'accelerate_sticky_content_sidebar_setting', array(
		'priority' => 7,
		'title' => esc_html__('Sticky Content And Sidebar', 'accelerate'),
		'panel' => 'accelerate_additional_options'
	) );

	$wp_customize->add_setting('accelerate[accelerate_sticky_content_sidebar]', array(
		'default' => 0,
		'type' => 'option',
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'accelerate_checkbox_sanitize'
	));

	$wp_customize->add_control('accelerate[accelerate_sticky_content_sidebar]', array(
		'type' => 'checkbox',
		'label' => esc_html__('Check to activate the sticky options for content and sidebar areas.', 'accelerate'),
		'setting' => 'accelerate[accelerate_sticky_content_sidebar]',
		'section' => 'accelerate_sticky_content_sidebar_setting'
	));
	// End of Additional Options

	// Adding Text Area Control For Use In Customizer
	class Accelerate_Text_Area_Control extends WP_Customize_Control {

		public $type = 'text_area';

		public function render_content() {
		?>
			<label>
				<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
				<textarea rows="5" style="width:100%;" <?php $this->link(); ?>><?php echo esc_textarea( $this->value() ); ?></textarea>
			</label>
		<?php
		}

	}

	// Start of the Slider Options
	$wp_customize->add_panel('accelerate_slider_options', array(
		'capabitity' => 'edit_theme_options',
		'priority' => 515,
		'title' => __('Slider', 'accelerate')
	));

	// Slider activate option
	$wp_customize->add_section('accelerate_slider_activate_section', array(
		'priority' => 1,
		'title' => __('Activate slider', 'accelerate'),
		'panel' => 'accelerate_slider_options'
	));

	$wp_customize->add_setting('accelerate[accelerate_activate_slider]', array(
		'default' => 0,
		'type' => 'option',
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'accelerate_checkbox_sanitize'
	));

	$wp_customize->add_control('accelerate[accelerate_activate_slider]', array(
		'type' => 'checkbox',
		'label' => __('Check to activate slider.', 'accelerate'),
		'section' => 'accelerate_slider_activate_section',
		'settings' => 'accelerate[accelerate_activate_slider]'
	));

	// Slider status option
	$wp_customize->add_section('accelerate_slider_status_section', array(
		'priority' => 2,
		'title' => __( 'Slider Status', 'accelerate' ),
		'panel' => 'accelerate_slider_options'
	));

	$wp_customize->add_setting('accelerate[accelerate_slider_status]', array(
		'default' => 'front_page',
		'type' => 'option',
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'accelerate_radio_select_sanitize'
	));

	$wp_customize->add_control('accelerate[accelerate_slider_status]', array(
		'type' => 'radio',
		'label' => __( 'Choose the slider status that you want.', 'accelerate' ),
		'setting' => 'accelerate[accelerate_slider_status]',
		'section' => 'accelerate_slider_status_section',
		'choices' => array(
			'front_page' => __( 'Slider on Front page', 'accelerate' ),
			'all_page' => __( 'Slider on all pages', 'accelerate' ),
		)
	));

	// Slider setting option
	$wp_customize->add_section('accelerate_slider_setting_section', array(
		'priority' => 3,
		'title' => __( 'Slider Settings', 'accelerate' ),
		'panel' => 'accelerate_slider_options'
	));

	$wp_customize->add_setting('accelerate[accelerate_slider_transition_effect]', array(
		'default' => 'fade',
		'type' => 'option',
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'accelerate_slider_radio_sanitize'
	));

	$wp_customize->add_control('accelerate[accelerate_slider_transition_effect]', array(
		'type' => 'select',
		'label' => __( 'Slider transition effect. Choose the transition effect that you like. Default is "fade".', 'accelerate' ),
		'setting' => 'accelerate[accelerate_slider_transition_effect]',
		'section' => 'accelerate_slider_setting_section',
		'choices' => array(
			'fade' => __( 'Fade', 'accelerate' ),
			'wipe' => __( 'Wipe', 'accelerate' ),
			'scrollUp' => __( 'scrollUp', 'accelerate' ),
			'scrollDown' => __( 'scrollDown', 'accelerate' ),
			'scrollLeft' => __( 'scrollLeft', 'accelerate' ),
			'scrollRight' => __( 'scrollRight', 'accelerate' ),
			'blindX' => __( 'blindX', 'accelerate' ),
			'blindY' => __( 'blindY', 'accelerate' ),
			'blindZ' => __( 'blindZ', 'accelerate' ),
			'cover' => __( 'Cover', 'accelerate' ),
			'shuffle' => __( 'Shuffle', 'accelerate' ),
		)
	));

	// Slider transition delay time
	$wp_customize->add_setting('accelerate[accelerate_slider_transition_delay]', array(
		'default' => 4,
		'type' => 'option',
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'accelerate_slider_transition_delay_sanitize'
	));

	$wp_customize->add_control('accelerate[accelerate_slider_transition_delay]', array(
		'label' => __( 'Slider transition delay time. Add number in seconds. Default is 4.', 'accelerate' ),
		'setting' => 'accelerate[accelerate_slider_transition_delay]',
		'section' => 'accelerate_slider_setting_section'
	));

	// Slider transition length time
	$wp_customize->add_setting('accelerate[accelerate_slider_transition_length]', array(
		'default' => 1,
		'type' => 'option',
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'accelerate_slider_transition_length_sanitize'
	));

	$wp_customize->add_control('accelerate[accelerate_slider_transition_length]', array(
		'label' => __( 'Slider transition length time. Add number in seconds. Default is 1.', 'accelerate' ),
		'setting' => 'accelerate[accelerate_slider_transition_length]',
		'section' => 'accelerate_slider_setting_section'
	));

	// slider number sanitize
	$wp_customize->add_setting('accelerate[accelerate_slider_number]', array(
		'default' => 4,
		'type' => 'option',
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'accelerate_slider_number_sanitize'
	));

	$wp_customize->add_control('accelerate[accelerate_slider_number]', array(
		'label' => __( 'Number of slides Enter the number of slides you want then click "Save Options".', 'accelerate' ),
		'setting' => 'accelerate[accelerate_slider_number]',
		'section' => 'accelerate_slider_setting_section'
	));

	// slider image link option
	$wp_customize->add_setting('accelerate[accelerate_slider_image_link_option]', array(
		'default' => 0,
		'type' => 'option',
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'accelerate_checkbox_sanitize'
	));

	$wp_customize->add_control('accelerate[accelerate_slider_image_link_option]', array(
		'type' => 'checkbox',
		'label' => __( 'Check to make the slider images link back to respective links.', 'accelerate' ),
		'section' => 'accelerate_slider_setting_section',
		'settings' => 'accelerate[accelerate_slider_image_link_option]'
	));

	// slider full width option
	$wp_customize->add_setting('accelerate[accelerate_slider_image_cover_full_width_option]', array(
		'default' => 0,
		'type' => 'option',
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'accelerate_checkbox_sanitize'
	));

	$wp_customize->add_control('accelerate[accelerate_slider_image_cover_full_width_option]', array(
		'type' => 'checkbox',
		'label' => __( 'Check to make the slider cover the full width of its container', 'accelerate' ),
		'section' => 'accelerate_slider_setting_section',
		'settings' => 'accelerate[accelerate_slider_image_cover_full_width_option]'
	));

	$num_of_slides = accelerate_options( 'accelerate_slider_number', '4' );
	for ( $i = 1; $i <= $num_of_slides; $i++ ) {
		// adding slider section
		$wp_customize->add_section('accelerate_slider_number_section'.$i, array(
			'priority' => 10,
			'title' => sprintf( __( 'Slider #%1$s', 'accelerate' ), $i ),
			'panel' => 'accelerate_slider_options'
		));

		// adding slider image url
		$wp_customize->add_setting('accelerate[accelerate_slider_image'.$i.']', array(
			'default' => '',
			'type' => 'option',
			'capability' => 'edit_theme_options',
			'sanitize_callback' => 'esc_url_raw'
		));

		$wp_customize->add_control(new WP_Customize_Image_Control($wp_customize, 'accelerate[accelerate_slider_image'.$i.']', array(
			'label' => __('Upload image', 'accelerate'),
			'section' => 'accelerate_slider_number_section'.$i,
			'setting' => 'accelerate[accelerate_slider_image'.$i.']'
		)));

		// adding slider title
		$wp_customize->add_setting('accelerate[accelerate_slider_title'.$i.']', array(
			'default' => '',
			'type' => 'option',
			'capability' => 'edit_theme_options',
			'sanitize_callback' => 'wp_filter_nohtml_kses'
		));

		$wp_customize->add_control('accelerate[accelerate_slider_title'.$i.']', array(
			'label' => __('Enter title for this slide','accelerate'),
			'section' => 'accelerate_slider_number_section'.$i,
			'setting' => 'accelerate[accelerate_slider_title'.$i.']'
		));

		// adding slider description
		$wp_customize->add_setting('accelerate[accelerate_slider_text'.$i.']', array(
			'default' => '',
			'type' => 'option',
			'capability' => 'edit_theme_options',
			'sanitize_callback' => 'accelerate_text_sanitize'
		));

		$wp_customize->add_control(new Accelerate_Text_Area_Control($wp_customize, 'accelerate[accelerate_slider_text'.$i.']', array(
			'label' => __('Enter description for this slide','accelerate'),
			'section' => 'accelerate_slider_number_section'.$i,
			'setting' => 'accelerate[accelerate_slider_text'.$i.']'
		)));

		// adding slider text position
		$wp_customize->add_setting('accelerate[accelerate_slide_text_position'.$i.']', array(
			'default' => 'right',
			'type' => 'option',
			'capability' => 'edit_theme_options',
			'sanitize_callback' => 'accelerate_radio_select_sanitize'
		));

		$wp_customize->add_control('accelerate[accelerate_slide_text_position'.$i.']', array(
			'type' => 'radio',
			'label' => __('Slider text position.','accelerate'),
			'section' => 'accelerate_slider_number_section'.$i,
			'setting' => 'accelerate[accelerate_slide_text_position'.$i.']',
			'choices' => array(
				'right' => __( 'Right side', 'accelerate' ),
				'left' => __( 'Left side', 'accelerate' )
			)
		));

		// adding button url
		$wp_customize->add_setting('accelerate[accelerate_slider_link'.$i.']', array(
			'default' => '',
			'type' => 'option',
			'capability' => 'edit_theme_options',
			'sanitize_callback' => 'esc_url_raw'
		));

		$wp_customize->add_control('accelerate[accelerate_slider_link'.$i.']', array(
			'label' => __('Enter link to redirect for the slide title','accelerate'),
			'section' => 'accelerate_slider_number_section'.$i,
			'setting' => 'accelerate[accelerate_slider_link'.$i.']'
		));
	}
	// End of Slider Options

	// Start of the Typography Options
	$wp_customize->add_panel('accelerate_typography_options', array(
		'capabitity' => 'edit_theme_options',
		'priority' => 520,
		'title' => __('Typography', 'accelerate')
	));

	$accelerate_fonts_families = array(
		'accelerate_site_title_font' => array(
			'id' => 'accelerate[accelerate_site_title_font]',
			'default' => 'Roboto+Slab:700,400',
			'title' => __( 'Site title font. Default is "Roboto Slab".', 'accelerate' ),
		),
		'accelerate_site_tagline_font' => array(
			'id' => 'accelerate[accelerate_site_tagline_font]',
			'default' => 'Roboto+Slab:700,400',
			'title' => __( 'Site tagline font. Default is "Roboto Slab".', 'accelerate' ),
		),
		'accelerate_primary_menu_font' => array(
			'id' => 'accelerate[accelerate_primary_menu_font]',
			'default' => 'Roboto:400,300,100',
			'title' => __( 'Primary menu font. Default is "Roboto".', 'accelerate' ),
		),
		'accelerate_header_menu_font' => array(
			'id' => 'accelerate[accelerate_header_menu_font]',
			'default' => 'Roboto:400,300,100',
			'title' => __( 'Header menu font. Default is "Roboto".', 'accelerate' ),
		),
		'accelerate_titles_font' => array(
			'id' => 'accelerate[accelerate_titles_font]',
			'default' => 'Roboto+Slab:700,400',
			'title' => __( 'All Titles font. Default is "Roboto Slab".', 'accelerate' ),
		),
		'accelerate_content_font' => array(
			'id' => 'accelerate[accelerate_content_font]',
			'default' => 'Roboto:400,300,100',
			'title' => __( 'Content font and for others. Default is "Roboto".', 'accelerate' ),
		),
	);

	$wp_customize->add_section('accelerate_google_font_section', array(
		'priority' => 1,
		'title' => __( 'Google Font Options', 'accelerate' ),
		'panel' => 'accelerate_typography_options'
	));

	foreach ($accelerate_fonts_families as $accelerate_fonts_family) {

		$wp_customize->add_setting($accelerate_fonts_family['id'], array(
			'default' => $accelerate_fonts_family['default'],
			'type' => 'option',
			'capability' => 'edit_theme_options',
			'sanitize_callback' => 'accelerate_fonts_sanitize'
		));

		// assigning the function for google font
		$accelerate_google_fonts_family = accelerate_google_fonts();

		$wp_customize->add_control($accelerate_fonts_family['id'], array(
			'label' => $accelerate_fonts_family['title'],
			'type' => 'select',
			'section' => 'accelerate_google_font_section',
			'setting' => $accelerate_fonts_family['id'],
			'choices' => $accelerate_google_fonts_family
		));

	}

	// Font Size options
	$accelerate_font_size_range_10_16 = array(
		'10' => '10',
		'11' => '11',
		'12' => '12',
		'13' => '13',
		'14' => '14',
		'15' => '15',
		'16' => '16'
	);
	$accelerate_font_size_range_10_18 = array(
		'10' => '10',
		'11' => '11',
		'12' => '12',
		'13' => '13',
		'14' => '14',
		'15' => '15',
		'16' => '16',
		'17' => '17',
		'18' => '18'
	);
	$accelerate_font_size_range_12_20 = array(
		'12' => '12',
		'13' => '13',
		'14' => '14',
		'15' => '15',
		'16' => '16',
		'17' => '17',
		'18' => '18',
		'19' => '19',
		'20' => '20'
	);
	$accelerate_font_size_range_16_30 = array(
		'16' => '16',
		'17' => '17',
		'18' => '18',
		'19' => '19',
		'20' => '20',
		'21' => '21',
		'22' => '22',
		'23' => '23',
		'24' => '24',
		'25' => '25',
		'26' => '26',
		'27' => '27',
		'28' => '28',
		'29' => '29',
		'30' => '30'
	);
	$accelerate_font_size_range_18_30 = array(
		'18' => '18',
		'19' => '19',
		'20' => '20',
		'21' => '21',
		'22' => '22',
		'23' => '23',
		'24' => '24',
		'25' => '25',
		'26' => '26',
		'27' => '27',
		'28' => '28',
		'29' => '29',
		'30' => '30'
	);
	$accelerate_font_size_range_20_34 = array(
		'20' => '20',
		'21' => '21',
		'22' => '22',
		'23' => '23',
		'24' => '24',
		'25' => '25',
		'26' => '26',
		'27' => '27',
		'28' => '28',
		'29' => '29',
		'30' => '30',
		'31' => '31',
		'32' => '32',
		'33' => '33',
		'34' => '34'
	);
	$accelerate_font_size_range_24_40 = array(
		'24' => '24',
		'25' => '25',
		'26' => '26',
		'27' => '27',
		'28' => '28',
		'29' => '29',
		'30' => '30',
		'31' => '31',
		'32' => '32',
		'33' => '33',
		'34' => '34',
		'35' => '35',
		'36' => '36',
		'37' => '37',
		'38' => '38',
		'39' => '39',
		'40' => '40'
	);
	$accelerate_font_size_range_26_46 = array(
		'26' => '26',
		'27' => '27',
		'28' => '28',
		'29' => '29',
		'30' => '30',
		'31' => '31',
		'32' => '32',
		'33' => '33',
		'34' => '34',
		'35' => '35',
		'36' => '36',
		'37' => '37',
		'38' => '38',
		'39' => '39',
		'40' => '40',
		'41' => '41',
		'42' => '42',
		'43' => '43',
		'44' => '44',
		'45' => '45',
		'46' => '46'
	);

	// header font size options
	$accelerate_header_font_sizes = array(
		'accelerate_site_title_font_size' => array(
			'id' => 'accelerate[accelerate_site_title_font_size]',
			'default' => '36',
			'title' => __( 'Site title font size. Default is 36px.', 'accelerate' ),
			'choice' => $accelerate_font_size_range_26_46
		),
		'accelerate_tagline_font_size' => array(
			'id' => 'accelerate[accelerate_tagline_font_size]',
			'default' => '16',
			'title' => __( 'Site tagline font size. Default is 16px.', 'accelerate' ),
			'choice' => $accelerate_font_size_range_12_20
		),
		'accelerate_primary_menu_font_size' => array(
			'id' => 'accelerate[accelerate_primary_menu_font_size]',
			'default' => '16',
			'title' => __( 'Primary menu. Default is 16px.', 'accelerate' ),
			'choice' => $accelerate_font_size_range_12_20
		),
		'accelerate_primary_sub_menu_font_size' => array(
			'id' => 'accelerate[accelerate_primary_sub_menu_font_size]',
			'default' => '14',
			'title' => __( 'Primary sub menu. Default is 14px.', 'accelerate' ),
			'choice' => $accelerate_font_size_range_10_18
		),
		'accelerate_header_menu_font_size' => array(
			'id' => 'accelerate[accelerate_header_menu_font_size]',
			'default' => '14',
			'title' => __( 'Header menu. Default is 14px.', 'accelerate' ),
			'choice' => $accelerate_font_size_range_10_18
		),
		'accelerate_header_sub_menu_font_size' => array(
			'id' => 'accelerate[accelerate_header_sub_menu_font_size]',
			'default' => '12',
			'title' => __( 'Header sub menu. Default is 12px.', 'accelerate' ),
			'choice' => $accelerate_font_size_range_10_16
		),
	);

	$wp_customize->add_section('accelerate_header_font_size_section', array(
		'priority' => 2,
		'title' => __( 'Header font size Options', 'accelerate' ),
		'panel' => 'accelerate_typography_options'
	));

	foreach ($accelerate_header_font_sizes as $accelerate_header_font_size) {

		$wp_customize->add_setting($accelerate_header_font_size['id'], array(
			'default' => $accelerate_header_font_size['default'],
			'type' => 'option',
			'capability' => 'edit_theme_options',
			'sanitize_callback' => 'accelerate_radio_select_sanitize'
		));

		$wp_customize->add_control($accelerate_header_font_size['id'], array(
			'label' => $accelerate_header_font_size['title'],
			'type' => 'select',
			'section' => 'accelerate_header_font_size_section',
			'setting' => $accelerate_header_font_size['id'],
			'choices' => $accelerate_header_font_size['choice'],
		));

	}

	// slider font size options
	$accelerate_slider_font_sizes = array(
		'accelerate_slider_title_font_size' => array(
			'id' => 'accelerate[accelerate_slider_title_font_size]',
			'default' => '22',
			'title' => __( 'Slider title. Default is 22px.', 'accelerate' ),
			'choice' => $accelerate_font_size_range_18_30
		),
		'accelerate_slider_content_font_size' => array(
			'id' => 'accelerate[accelerate_slider_content_font_size]',
			'default' => '15',
			'title' => __( 'Slider content. Default is 15px.', 'accelerate' ),
			'choice' => $accelerate_font_size_range_10_18
		),
	);

	$wp_customize->add_section('accelerate_slider_font_size_section', array(
		'priority' => 3,
		'title' => __( 'Slider font size Options', 'accelerate' ),
		'panel' => 'accelerate_typography_options'
	));

	foreach ($accelerate_slider_font_sizes as $accelerate_slider_font_size) {

		$wp_customize->add_setting($accelerate_slider_font_size['id'], array(
			'default' => $accelerate_slider_font_size['default'],
			'type' => 'option',
			'capability' => 'edit_theme_options',
			'sanitize_callback' => 'accelerate_radio_select_sanitize'
		));

		$wp_customize->add_control($accelerate_slider_font_size['id'], array(
			'label' => $accelerate_slider_font_size['title'],
			'type' => 'select',
			'section' => 'accelerate_slider_font_size_section',
			'setting' => $accelerate_slider_font_size['id'],
			'choices' => $accelerate_slider_font_size['choice'],
		));

	}

	// title font size options
	$accelerate_titles_font_sizes = array(
		'accelerate_h1_title_font_size' => array(
			'id' => 'accelerate[accelerate_h1_title_font_size]',
			'default' => '30',
			'title' => __( 'Heading h1 tag. Default is 30px.', 'accelerate' ),
			'choice' => $accelerate_font_size_range_24_40
		),
		'accelerate_h2_title_font_size' => array(
			'id' => 'accelerate[accelerate_h2_title_font_size]',
			'default' => '28',
			'title' => __( 'Heading h2 tag. Default is 28px.', 'accelerate' ),
			'choice' => $accelerate_font_size_range_20_34
		),
		'accelerate_h3_title_font_size' => array(
			'id' => 'accelerate[accelerate_h3_title_font_size]',
			'default' => '26',
			'title' => __( 'Heading h3 tag. Default is 26px.', 'accelerate' ),
			'choice' => $accelerate_font_size_range_20_34
		),
		'accelerate_h4_title_font_size' => array(
			'id' => 'accelerate[accelerate_h4_title_font_size]',
			'default' => '24',
			'title' => __( 'Heading h4 tag. Default is 24px.', 'accelerate' ),
			'choice' => $accelerate_font_size_range_18_30
		),
		'accelerate_h5_title_font_size' => array(
			'id' => 'accelerate[accelerate_h5_title_font_size]',
			'default' => '22',
			'title' => __( 'Heading h5 tag. Default is 22px.', 'accelerate' ),
			'choice' => $accelerate_font_size_range_16_30
		),
		'accelerate_h6_title_font_size' => array(
			'id' => 'accelerate[accelerate_h6_title_font_size]',
			'default' => '19',
			'title' => __( 'Heading h6 tag. Default is 19px.', 'accelerate' ),
			'choice' => $accelerate_font_size_range_16_30
		),
		'accelerate_image_service_widget_title_font_size' => array(
			'id' => 'accelerate[accelerate_image_service_widget_title_font_size]',
			'default' => '22',
			'title' => __( 'TG: Image Services widget title. Default is 22px.', 'accelerate' ),
			'choice' => $accelerate_font_size_range_16_30
		),
		'accelerate_call_to_action_widget_title_font_size' => array(
			'id' => 'accelerate[accelerate_call_to_action_widget_title_font_size]',
			'default' => '28',
			'title' => __( 'TG: Call to Action widget title. Default is 28px.', 'accelerate' ),
			'choice' => $accelerate_font_size_range_20_34
		),
		'accelerate_featured_widget_titles_font_size' => array(
			'id' => 'accelerate[accelerate_featured_widget_titles_font_size]',
			'default' => '16',
			'title' => __( 'TG: Featured Widget titles that appear over images. Default is 16px.', 'accelerate' ),
			'choice' => $accelerate_font_size_range_12_20
		),
		'accelerate_widget_titles_font_size' => array(
			'id' => 'accelerate[accelerate_widget_titles_font_size]',
			'default' => '22',
			'title' => __( 'Widget Titles. Default is 22px.', 'accelerate' ),
			'choice' => $accelerate_font_size_range_16_30
		),
		'accelerate_post_title_font_size' => array(
			'id' => 'accelerate[accelerate_post_title_font_size]',
			'default' => '26',
			'title' => __( 'Post Title. Default is 26px.', 'accelerate' ),
			'choice' => $accelerate_font_size_range_20_34
		),
		'accelerate_page_title_font_size' => array(
			'id' => 'accelerate[accelerate_page_title_font_size]',
			'default' => '30',
			'title' => __( 'Page Title. Default is 30px.', 'accelerate' ),
			'choice' => $accelerate_font_size_range_20_34
		),
		'accelerate_comment_title_font_size' => array(
			'id' => 'accelerate[accelerate_comment_title_font_size]',
			'default' => '26',
			'title' => __( 'Comment Title. Default is 26px.', 'accelerate' ),
			'choice' => $accelerate_font_size_range_20_34
		),
	);

	$wp_customize->add_section('accelerate_titles_font_size_section', array(
		'priority' => 4,
		'title' => __( 'Titles related font size options', 'accelerate' ),
		'panel' => 'accelerate_typography_options'
	));

	foreach ($accelerate_titles_font_sizes as $accelerate_titles_font_size) {

		$wp_customize->add_setting($accelerate_titles_font_size['id'], array(
			'default' => $accelerate_titles_font_size['default'],
			'type' => 'option',
			'capability' => 'edit_theme_options',
			'sanitize_callback' => 'accelerate_radio_select_sanitize'
		));

		$wp_customize->add_control($accelerate_titles_font_size['id'], array(
			'label' => $accelerate_titles_font_size['title'],
			'type' => 'select',
			'section' => 'accelerate_titles_font_size_section',
			'setting' => $accelerate_titles_font_size['id'],
			'choices' => $accelerate_titles_font_size['choice'],
		));

	}

	// content font sizes
	$accelerate_content_font_sizes = array(
		'accelerate_content_font_size' => array(
			'id' => 'accelerate[accelerate_content_font_size]',
			'default' => '16',
			'title' => __( 'Content font size, also applies to other text like in search fields, post comment button etc. Default is 16px.', 'accelerate' ),
			'choice' => $accelerate_font_size_range_12_20
		),
		'accelerate_post_meta_font_size' => array(
			'id' => 'accelerate[accelerate_post_meta_font_size]',
			'default' => '16',
			'title' => __( 'Post meta font size: author and categories. Default is 16px.', 'accelerate' ),
			'choice' => $accelerate_font_size_range_12_20
		),
		'accelerate_other_post_meta_font_size' => array(
			'id' => 'accelerate[accelerate_other_post_meta_font_size]',
			'default' => '12',
			'title' => __( 'Post meta font size: other than author and categories. Default is 12px.', 'accelerate' ),
			'choice' => $accelerate_font_size_range_10_18
		),
	);

	$wp_customize->add_section('accelerate_content_font_size_section', array(
		'priority' => 5,
		'title' => __( 'Content font size options', 'accelerate' ),
		'panel' => 'accelerate_typography_options'
	));

	foreach ($accelerate_content_font_sizes as $accelerate_content_font_size) {

		$wp_customize->add_setting($accelerate_content_font_size['id'], array(
			'default' => $accelerate_content_font_size['default'],
			'type' => 'option',
			'capability' => 'edit_theme_options',
			'sanitize_callback' => 'accelerate_radio_select_sanitize'
		));

		$wp_customize->add_control($accelerate_content_font_size['id'], array(
			'label' => $accelerate_content_font_size['title'],
			'type' => 'select',
			'section' => 'accelerate_content_font_size_section',
			'setting' => $accelerate_content_font_size['id'],
			'choices' => $accelerate_content_font_size['choice'],
		));

	}

	// footer font sizes
	$accelerate_footer_font_sizes = array(
		'accelerate_footer_widget_titles_font_size' => array(
			'id' => 'accelerate[accelerate_footer_widget_titles_font_size]',
			'default' => '22',
			'title' => __( 'Footer widget Titles. Default is 22px.', 'accelerate' ),
			'choice' => $accelerate_font_size_range_16_30
		),
		'accelerate_footer_widget_content_font_size' => array(
			'id' => 'accelerate[accelerate_footer_widget_content_font_size]',
			'default' => '14',
			'title' => __( 'Footer widget content font size. Default is 14px.', 'accelerate' ),
			'choice' => $accelerate_font_size_range_10_18
		),
		'accelerate_footer_copyright_text_font_size' => array(
			'id' => 'accelerate[accelerate_footer_copyright_text_font_size]',
			'default' => '12',
			'title' => __( 'Footer copyright text font size. Default is 12px.', 'accelerate' ),
			'choice' => $accelerate_font_size_range_10_16
		),
		'accelerate_small_footer_menu_font_size' => array(
			'id' => 'accelerate[accelerate_small_footer_menu_font_size]',
			'default' => '12',
			'title' => __( 'Footer small menu. Default is 12px.', 'accelerate' ),
			'choice' => $accelerate_font_size_range_10_16
		),
	);

	$wp_customize->add_section('accelerate_footer_font_size_section', array(
		'priority' => 5,
		'title' => __( 'Footer font size options', 'accelerate' ),
		'panel' => 'accelerate_typography_options'
	));

	foreach ($accelerate_footer_font_sizes as $accelerate_footer_font_size) {

		$wp_customize->add_setting($accelerate_footer_font_size['id'], array(
			'default' => $accelerate_footer_font_size['default'],
			'type' => 'option',
			'capability' => 'edit_theme_options',
			'sanitize_callback' => 'accelerate_radio_select_sanitize'
		));

		$wp_customize->add_control($accelerate_footer_font_size['id'], array(
			'label' => $accelerate_footer_font_size['title'],
			'type' => 'select',
			'section' => 'accelerate_footer_font_size_section',
			'setting' => $accelerate_footer_font_size['id'],
			'choices' => $accelerate_footer_font_size['choice'],
		));

	}
	// End of Typography Options

	// Start of Color Options
	$wp_customize->add_panel('accelerate_color_options', array(
		'capabitity' => 'edit_theme_options',
		'priority' => 525,
		'title' => __('Color', 'accelerate')
	));

	// Site primary color option
	$wp_customize->add_section('accelerate_primary_color_setting', array(
		'panel' => 'accelerate_color_options',
		'priority' => 1,
		'title' => __('Primary color option', 'accelerate')
	));

	$wp_customize->add_setting('accelerate[accelerate_primary_color]', array(
		'default' => '#77cc6d',
		'type' => 'option',
		'capability' => 'edit_theme_options',
		'sanitize_callback' => 'accelerate_color_option_hex_sanitize',
		'sanitize_js_callback' => 'accelerate_color_escaping_option_sanitize'
	));

	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'accelerate[accelerate_primary_color]', array(
		'label' => __('This will reflect in links, buttons and many others. Choose a color to match your site.', 'accelerate'),
		'section' => 'accelerate_primary_color_setting',
		'settings' => 'accelerate[accelerate_primary_color]'
	)));

	// Font Color options
	// header color options
	$accelerate_header_colors = array(
		'accelerate_site_title_text_color' => array(
			'id' => 'accelerate[accelerate_site_title_text_color]',
			'title' => __( 'Site Title. Default is #555555.', 'accelerate' ),
			'default' => '#555555'
		),
		'accelerate_site_tagline_text_color' => array(
			'id' => 'accelerate[accelerate_site_tagline_text_color]',
			'title' => __( 'Site Tagline. Default is #999999.', 'accelerate' ),
			'default' => '#999999'
		),
		'accelerate_primary_menu_text_color' => array(
			'id' => 'accelerate[accelerate_primary_menu_text_color]',
			'title' => __( 'Primary menu text color. Default is #444444.', 'accelerate' ),
			'default' => '#444444'
		),
		'accelerate_primary_menu_background_color' => array(
			'id' => 'accelerate[accelerate_primary_menu_background_color]',
			'title' => __( 'Primary menu selected/hovered item background color. Default is #77cc6d.', 'accelerate' ),
			'default' => '#77cc6d'
		),
		'accelerate_primary_menu_bar_background_color' => array(
			'id' => 'accelerate[accelerate_primary_menu_bar_background_color]',
			'title' => __( 'Primary menu bar (unselected/unhovered) background color. Default is #ffffff.', 'accelerate' ),
			'default' => '#ffffff'
		),
		'accelerate_header_background_color' => array(
			'id' => 'accelerate[accelerate_header_background_color]',
			'title' => __( 'Header background color. Default is #f8f8f8.', 'accelerate' ),
			'default' => '#f8f8f8'
		),
		'accelerate_header_top_bar_background_color' => array(
			'id' => 'accelerate[accelerate_header_top_bar_background_color]',
			'title' => __( 'Header top bar background color. Default is #262626.', 'accelerate' ),
			'default' => '#262626'
		),
		'accelerate_top_menu_item_color' => array(
			'id' => 'accelerate[accelerate_top_menu_item_color]',
			'title' => __( 'Header top menu item text color. Default is #cccccc.', 'accelerate' ),
			'default' => '#cccccc'
		),
		'accelerate_top_menu_selected_item_color' => array(
			'id' => 'accelerate[accelerate_top_menu_selected_item_color]',
			'title' => __( 'Header top menu seleted/hovered item text color. Default is #ffffff.', 'accelerate' ),
			'default' => '#ffffff'
		),
		'accelerate_top_menu_dropdown_background_color' => array(
			'id' => 'accelerate[accelerate_top_menu_dropdown_background_color]',
			'title' => __( 'Header menu dropdown background color. Default is #262626.', 'accelerate' ),
			'default' => '#262626'
		),
		'accelerate_header_top_line_color' => array(
			'id' => 'accelerate[accelerate_header_top_line_color]',
			'title' => __( 'Header top line color. Default is #77cc6d.', 'accelerate' ),
			'default' => '#77cc6d'
		),
	);

	$wp_customize->add_section('accelerate_header_color_section', array(
		'priority' => 2,
		'title' => __( 'Header Color Options', 'accelerate' ),
		'panel' => 'accelerate_color_options'
	));

	foreach ($accelerate_header_colors as $accelerate_header_color) {

		$wp_customize->add_setting($accelerate_header_color['id'], array(
			'default' => $accelerate_header_color['default'],
			'type' => 'option',
			'capability' => 'edit_theme_options',
			'sanitize_callback' => 'accelerate_color_option_hex_sanitize',
			'sanitize_js_callback' => 'accelerate_color_escaping_option_sanitize'
		));

		$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, $accelerate_header_color['id'], array(
			'label' => $accelerate_header_color['title'],
			'section' => 'accelerate_header_color_section',
			'settings' => $accelerate_header_color['id']
		)));

	}

	// slider part color options
	$accelerate_slider_colors = array(
		'accelerate_slider_title_color' => array(
			'id' => 'accelerate[accelerate_slider_title_color]',
			'title' => __( 'Slider title. Default is #ffffff.', 'accelerate' ),
			'default' => '#ffffff'
		),
		'accelerate_slider_title_background_color' => array(
			'id' => 'accelerate[accelerate_slider_title_background_color]',
			'title' => __( 'Slider title box background color. Default is #77cc6d.', 'accelerate' ),
			'default' => '#77cc6d'
		),
		'accelerate_slider_content_color' => array(
			'id' => 'accelerate[accelerate_slider_content_color]',
			'title' => __( 'Slider content. Default is #ffffff.', 'accelerate' ),
			'default' => '#ffffff'
		),
		'accelerate_slider_background_color' => array(
			'id' => 'accelerate[accelerate_slider_background_color]',
			'title' => __( 'Slider background color. Default is #ffffff.', 'accelerate' ),
			'default' => '#ffffff'
		),
	);

	$wp_customize->add_section('accelerate_slider_color_section', array(
		'priority' => 3,
		'title' => __( 'Slider part color options', 'accelerate' ),
		'panel' => 'accelerate_color_options'
	));

	foreach ($accelerate_slider_colors as $accelerate_slider_color) {

		$wp_customize->add_setting($accelerate_slider_color['id'], array(
			'default' => $accelerate_slider_color['default'],
			'type' => 'option',
			'capability' => 'edit_theme_options',
			'sanitize_callback' => 'accelerate_color_option_hex_sanitize',
			'sanitize_js_callback' => 'accelerate_color_escaping_option_sanitize'
		));

		$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, $accelerate_slider_color['id'], array(
			'label' => $accelerate_slider_color['title'],
			'section' => 'accelerate_slider_color_section',
			'settings' => $accelerate_slider_color['id']
		)));

	}

	// content color options
	$accelerate_content_colors = array(
		'accelerate_content_part_titles_color' => array(
			'id' => 'accelerate[accelerate_content_part_titles_color]',
			'title' => __( 'Content Part titles color. Default is #444444.', 'accelerate' ),
			'default' => '#444444'
		),
		'accelerate_posts_title_color' => array(
			'id' => 'accelerate[accelerate_posts_title_color]',
			'title' => __( 'Posts title color. Default is #444444.', 'accelerate' ),
			'default' => '#444444'
		),
		'accelerate_page_title_color' => array(
			'id' => 'accelerate[accelerate_page_title_color]',
			'title' => __( 'Page title color. Default is #444444.', 'accelerate' ),
			'default' => '#444444'
		),
		'accelerate_content_text_color' => array(
			'id' => 'accelerate[accelerate_content_text_color]',
			'title' => __( 'Content text color. Default is #666666.', 'accelerate' ),
			'default' => '#666666'
		),
		'accelerate_post_meta_color' => array(
			'id' => 'accelerate[accelerate_post_meta_color]',
			'title' => __( 'Post meta (author and category) color. Default is #77cc6d.', 'accelerate' ),
			'default' => '#77cc6d'
		),
		'accelerate_post_other_meta_color' => array(
			'id' => 'accelerate[accelerate_post_other_meta_color]',
			'title' => __( 'Post meta (other than author and category) color. Default is #aaaaaa.', 'accelerate' ),
			'default' => '#aaaaaa'
		),
		'accelerate_button_text_color' => array(
			'id' => 'accelerate[accelerate_button_text_color]',
			'title' => __( 'Button text color. Default is #ffffff.', 'accelerate' ),
			'default' => '#ffffff'
		),
		'accelerate_button_background_color' => array(
			'id' => 'accelerate[accelerate_button_background_color]',
			'title' => __( 'Button background color. Default is #77cc6d.', 'accelerate' ),
			'default' => '#77cc6d'
		),
		'accelerate_widget_title_color' => array(
			'id' => 'accelerate[accelerate_widget_title_color]',
			'title' => __( 'Left and Right sidebar widget title color. Default is #444444.', 'accelerate' ),
			'default' => '#444444'
		),
		'accelerate_content_background_color' => array(
			'id' => 'accelerate[accelerate_content_background_color]',
			'title' => __( 'Content section background color. Default is #ffffff.', 'accelerate' ),
			'default' => '#ffffff'
		),
		'accelerate_call_to_action_background_color' => array(
			'id' => 'accelerate[accelerate_call_to_action_background_color]',
			'title' => __( 'TG: Call to Action widget background color. Default is #f8f8f8.', 'accelerate' ),
			'default' => '#f8f8f8'
		),
		'accelerate_testimonial_background_color' => array(
			'id' => 'accelerate[accelerate_testimonial_background_color]',
			'title' => __( 'TG: Testimonial widget text background color. Default is #fcfcfc.', 'accelerate' ),
			'default' => '#fcfcfc'
		),
	);

	$wp_customize->add_section('accelerate_content_color_section', array(
		'priority' => 4,
		'title' => __( 'Content part color options', 'accelerate' ),
		'panel' => 'accelerate_color_options'
	));

	foreach ($accelerate_content_colors as $accelerate_content_color) {

		$wp_customize->add_setting($accelerate_content_color['id'], array(
			'default' => $accelerate_content_color['default'],
			'type' => 'option',
			'capability' => 'edit_theme_options',
			'sanitize_callback' => 'accelerate_color_option_hex_sanitize',
			'sanitize_js_callback' => 'accelerate_color_escaping_option_sanitize'
		));

		$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, $accelerate_content_color['id'], array(
			'label' => $accelerate_content_color['title'],
			'section' => 'accelerate_content_color_section',
			'settings' => $accelerate_content_color['id']
		)));

	}

	// footer color options
	$accelerate_footer_colors = array(
		'accelerate_footer_widget_title_color' => array(
			'id' => 'accelerate[accelerate_footer_widget_title_color]',
			'title' => __( 'Widget title color. Default is #ffffff.', 'accelerate' ),
			'default' => '#ffffff'
		),
		'accelerate_footer_widget_content_color' => array(
			'id' => 'accelerate[accelerate_footer_widget_content_color]',
			'title' => __( 'Footer widget content color. Default is #aaaaaa.', 'accelerate' ),
			'default' => '#aaaaaa'
		),
		'accelerate_footer_widget_link_color' => array(
			'id' => 'accelerate[accelerate_footer_widget_link_color]',
			'title' => __( 'Footer widget content link text color. Default is #ffffff.', 'accelerate' ),
			'default' => '#ffffff'
		),
		'accelerate_footer_widget_background_color' => array(
			'id' => 'accelerate[accelerate_footer_widget_background_color]',
			'title' => __( 'Footer widget background color. Default is #27313d.', 'accelerate' ),
			'default' => '#27313d'
		),
		'accelerate_footer_copyright_text_color' => array(
			'id' => 'accelerate[accelerate_footer_copyright_text_color]',
			'title' => __( 'Footer copyright text color. Default is #666666.', 'accelerate' ),
			'default' => '#666666'
		),
		'accelerate_footer_small_menu_color' => array(
			'id' => 'accelerate[accelerate_footer_small_menu_color]',
			'title' => __( 'Footer small menu text color. Default is #666666.', 'accelerate' ),
			'default' => '#666666'
		),
		'accelerate_footer_copyright_part_background_color' => array(
			'id' => 'accelerate[accelerate_footer_copyright_part_background_color]',
			'title' => __( 'Footer copyright part background color. Default is #f8f8f8.', 'accelerate' ),
			'default' => '#f8f8f8'
		),
	);

	$wp_customize->add_section('accelerate_footer_color_section', array(
		'priority' => 5,
		'title' => __( 'Footer part color options', 'accelerate' ),
		'panel' => 'accelerate_color_options'
	));

	foreach ($accelerate_footer_colors as $accelerate_footer_color) {

		$wp_customize->add_setting($accelerate_footer_color['id'], array(
			'default' => $accelerate_footer_color['default'],
			'type' => 'option',
			'capability' => 'edit_theme_options',
			'sanitize_callback' => 'accelerate_color_option_hex_sanitize',
			'sanitize_js_callback' => 'accelerate_color_escaping_option_sanitize'
		));

		$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, $accelerate_footer_color['id'], array(
			'label' => $accelerate_footer_color['title'],
			'section' => 'accelerate_footer_color_section',
			'settings' => $accelerate_footer_color['id']
		)));

	}
	// End of Color Options

	// Start of data sanitization
	// radio/select sanitize
	function accelerate_radio_select_sanitize( $input, $setting ) {
		// Ensuring that the input is a slug.
		$input = sanitize_key( $input );
		// Get the list of choices from the control associated with the setting.
		$choices = $setting->manager->get_control( $setting->id )->choices;
		// If the input is a valid key, return it, else, return the default.
		return ( array_key_exists( $input, $choices ) ? $input : $setting->default );
	}

	// Slider radio sanitize
	function accelerate_slider_radio_sanitize( $input, $setting ) {
		// Ensuring that the input is a slug.
		$input = sanitize_text_field( $input );
		// Get the list of choices from the control associated with the setting.
		$choices = $setting->manager->get_control( $setting->id )->choices;
		// If the input is a valid key, return it, else, return the default.
		return ( array_key_exists( $input, $choices ) ? $input : $setting->default );
	}

	// google fonts sanitize
	function accelerate_fonts_sanitize( $input, $setting ) {
		// Get the list of choices from the control associated with the setting.
		$choices = $setting->manager->get_control( $setting->id )->choices;
		// If the input is a valid key, return it, else, return the default.
		return ( array_key_exists( $input, $choices ) ? $input : $setting->default );
	}

	// checkbox sanitize
	function accelerate_checkbox_sanitize($input) {
		if ( $input == 1 ) {
			return 1;
		} else {
			return '';
		}
	}

	// footer section sanitization
	function accelerate_footer_editor_sanitize( $input) {
		if( isset( $input ) ) {
			$input =  stripslashes( wp_filter_post_kses( addslashes ( $input ) ) );
		}
		return $input;
	}

	// color sanitization
	function accelerate_color_option_hex_sanitize($color) {
		if ($unhashed = sanitize_hex_color_no_hash($color))
			return '#' . $unhashed;

		return $color;
	}

	function accelerate_color_escaping_option_sanitize($input) {
		$input = esc_attr($input);
		return $input;
	}

	// text-area sanitize
	function accelerate_text_sanitize($input) {
		return wp_kses_post( force_balance_tags( $input ) );
	}

	// excerpt length sanitize
	function accelerate_excerpt_length_sanitize($input) {
		if( is_numeric( $input ) ) {
			return intval( $input );
		}
		else
			return 40;
	}

	// slider transition delay time sanitize
	function accelerate_slider_transition_delay_sanitize($input) {
		if( is_numeric( $input ) ) {
			return intval( $input );
		}
		else
			return 4;
	}

	// slider transition length sanitize
	function accelerate_slider_transition_length_sanitize($input) {
		if( is_numeric( $input ) ) {
			return intval( $input );
		}
		else
			return 1;
	}

	// slider number sanitize
	function accelerate_slider_number_sanitize($input) {
		if( is_numeric( $input ) ) {
			return intval( $input );
		}
		else
			return 4;
	}

	// sanitization of links
	function accelerate_links_sanitize() {
		return false;
	}

}
add_action('customize_register', 'accelerate_customize_register');

function accelerate_google_fonts() {

	$accelerate_googlefonts = array(
		"ABeeZee" => "ABeeZee",
		"Abel" => "Abel",
		"Abril Fatface" => "Abril+Fatface",
		"Aclonica" => "Aclonica",
		"Acme" => "Acme",
		"Actor" => "Actor",
		"Adamina" => "Adamina",
		"Advent Pro" => "Advent+Pro",
		"Aguafina Script" => "Aguafina+Script",
		"Akronim" => "Akronim",
		"Aladin" => "Aladin",
		"Aldrich" => "Aldrich",
		"Alegreya" => "Alegreya",
		"Alegreya SC" => "Alegreya+SC",
		"Alex Brush" => "Alex+Brush",
		"Alfa Slab One" => "Alfa+Slab+One",
		"Alice" => "Alice",
		"Alike" => "Alike",
		"Alike Angular" => "Alike+Angular",
		"Allan" => "Allan",
		"Allerta" => "Allerta",
		"Allerta Stencil" => "Allerta+Stencil",
		"Allura" => "Allura",
		"Almendra" => "Almendra",
		"Almendra Display" => "Almendra+Display",
		"Almendra SC" => "Almendra+SC",
		"Amarante" => "Amarante",
		"Amaranth" => "Amaranth",
		"Amatic SC" => "Amatic+SC",
		"Amethysta" => "Amethysta",
		"Anaheim" => "Anaheim",
		"Andada" => "Andada",
		"Andika" => "Andika",
		"Angkor" => "Angkor",
		"Annie Use Your Telescope" => "Annie+Use+Your+Telescope",
		"Anonymous Pro" => "Anonymous+Pro",
		"Antic" => "Antic",
		"Antic Didone" => "Antic+Didone",
		"Antic Slab" => "Antic+Slab",
		"Anton" => "Anton",
		"Arapey" => "Arapey",
		"Arbutus" => "Arbutus",
		"Arbutus Slab" => "Arbutus+Slab",
		"Architects Daughter" => "Architects+Daughter",
		"Archivo Black" => "Archivo+Black",
		"Archivo Narrow" => "Archivo+Narrow",
		"Arimo" => "Arimo",
		"Arizonia" => "Arizonia",
		"Armata" => "Armata",
		"Artifika" => "Artifika",
		"Arvo" => "Arvo",
		"Asap" => "Asap",
		"Asset" => "Asset",
		"Astloch" => "Astloch",
		"Asul" => "Asul",
		"Atomic Age" => "Atomic+Age",
		"Aubrey" => "Aubrey",
		"Audiowide" => "Audiowide",
		"Autour One" => "Autour+One",
		"Average" => "Average",
		"Average Sans" => "Average+Sans",
		"Averia Gruesa Libre" => "Averia+Gruesa+Libre",
		"Averia Libre" => "Averia+Libre",
		"Averia Sans Libre" => "Averia+Sans+Libre",
		"Averia Serif Libre" => "Averia+Serif+Libre",
		"Bad Script" => "Bad+Script",
		"Balthazar" => "Balthazar",
		"Bangers" => "Bangers",
		"Basic" => "Basic",
		"Battambang" => "Battambang",
		"Baumans" => "Baumans",
		"Bayon" => "Bayon",
		"Belgrano" => "Belgrano",
		"Belleza" => "Belleza",
		"BenchNine" => "BenchNine",
		"Bentham" => "Bentham",
		"Berkshire Swash" => "Berkshire+Swash",
		"Bevan" => "Bevan",
		"Bigelow Rules" => "Bigelow+Rules",
		"Bigshot One" => "Bigshot+One",
		"Bilbo" => "Bilbo",
		"Bilbo Swash Caps" => "Bilbo+Swash+Caps",
		"Bitter" => "Bitter",
		"Black Ops One" => "Black+Ops+One",
		"Bokor" => "Bokor",
		"Bonbon" => "Bonbon",
		"Boogaloo" => "Boogaloo",
		"Bowlby One" => "Bowlby+One",
		"Bowlby One SC" => "Bowlby+One+SC",
		"Brawler" => "Brawler",
		"Bree Serif" => "Bree+Serif",
		"Bubblegum Sans" => "Bubblegum+Sans",
		"Bubbler One" => "Bubbler+One",
		"Buda" => "Buda",
		"Buenard" => "Buenard",
		"Butcherman" => "Butcherman",
		"Butterfly Kids" => "Butterfly+Kids",
		"Cabin" => "Cabin",
		"Cabin Condensed" => "Cabin+Condensed",
		"Cabin Sketch" => "Cabin+Sketch",
		"Caesar Dressing" => "Caesar+Dressing",
		"Cagliostro" => "Cagliostro",
		"Calligraffitti" => "Calligraffitti",
		"Cambo" => "Cambo",
		"Candal" => "Candal",
		"Cantarell" => "Cantarell",
		"Cantata One" => "Cantata+One",
		"Cantora One" => "Cantora+One",
		"Capriola" => "Capriola",
		"Cardo" => "Cardo",
		"Carme" => "Carme",
		"Carrois Gothic" => "Carrois+Gothic",
		"Carrois Gothic SC" => "Carrois+Gothic+SC",
		"Carter One" => "Carter+One",
		"Caudex" => "Caudex",
		"Cedarville Cursive" => "Cedarville+Cursive",
		"Ceviche One" => "Ceviche+One",
		"Changa One" => "Changa+One",
		"Chango" => "Chango",
		"Chau Philomene One" => "Chau+Philomene+One",
		"Chela One" => "Chela+One",
		"Chelsea Market" => "Chelsea+Market",
		"Chenla" => "Chenla",
		"Cherry Cream Soda" => "Cherry+Cream+Soda",
		"Cherry Swash" => "Cherry+Swash",
		"Chewy" => "Chewy",
		"Chicle" => "Chicle",
		"Chivo" => "Chivo",
		"Cinzel" => "Cinzel",
		"Cinzel Decorative" => "Cinzel+Decorative",
		"Clicker Script" => "Clicker+Script",
		"Coda" => "Coda",
		"Coda Caption" => "Coda+Caption",
		"Codystar" => "Codystar",
		"Combo" => "Combo",
		"Comfortaa" => "Comfortaa",
		"Coming Soon" => "Coming+Soon",
		"Concert One" => "Concert+One",
		"Condiment" => "Condiment",
		"Content" => "Content",
		"Contrail One" => "Contrail+One",
		"Convergence" => "Convergence",
		"Cookie" => "Cookie",
		"Copse" => "Copse",
		"Corben" => "Corben",
		"Courgette" => "Courgette",
		"Cousine" => "Cousine",
		"Coustard" => "Coustard",
		"Covered By Your Grace" => "Covered+By+Your+Grace",
		"Crafty Girls" => "Crafty+Girls",
		"Creepster" => "Creepster",
		"Crete Round" => "Crete+Round",
		"Crimson Text" => "Crimson+Text",
		"Croissant One" => "Croissant+One",
		"Crushed" => "Crushed",
		"Cuprum" => "Cuprum",
		"Cutive" => "Cutive",
		"Cutive Mono" => "Cutive+Mono",
		"Damion" => "Damion",
		"Dancing Script" => "Dancing+Script",
		"Dangrek" => "Dangrek",
		"Dawning of a New Day" => "Dawning+of+a+New+Day",
		"Days One" => "Days+One",
		"Delius" => "Delius",
		"Delius Swash Caps" => "Delius+Swash+Caps",
		"Delius Unicase" => "Delius+Unicase",
		"Della Respira" => "Della+Respira",
		"Denk One" => "Denk+One",
		"Devonshire" => "Devonshire",
		"Didact Gothic" => "Didact+Gothic",
		"Diplomata" => "Diplomata",
		"Diplomata SC" => "Diplomata+SC",
		"Domine" => "Domine",
		"Donegal One" => "Donegal+One",
		"Doppio One" => "Doppio+One",
		"Dorsa" => "Dorsa",
		"Dosis" => "Dosis",
		"Dr Sugiyama" => "Dr+Sugiyama",
		"Droid Sans" => "Droid+Sans",
		"Droid Sans Mono" => "Droid+Sans+Mono",
		"Droid Serif" => "Droid+Serif",
		"Duru Sans" => "Duru+Sans",
		"Dynalight" => "Dynalight",
		"EB Garamond" => "EB+Garamond",
		"Eagle Lake" => "Eagle+Lake",
		"Eater" => "Eater",
		"Economica" => "Economica",
		"Electrolize" => "Electrolize",
		"Elsie" => "Elsie",
		"Elsie Swash Caps" => "Elsie+Swash+Caps",
		"Emblema One" => "Emblema+One",
		"Emilys Candy" => "Emilys+Candy",
		"Engagement" => "Engagement",
		"Englebert" => "Englebert",
		"Enriqueta" => "Enriqueta",
		"Erica One" => "Erica+One",
		"Esteban" => "Esteban",
		"Euphoria Script" => "Euphoria+Script",
		"Ewert" => "Ewert",
		"Exo" => "Exo",
		"Expletus Sans" => "Expletus+Sans",
		"Fanwood Text" => "Fanwood+Text",
		"Fascinate" => "Fascinate",
		"Fascinate Inline" => "Fascinate+Inline",
		"Faster One" => "Faster+One",
		"Fasthand" => "Fasthand",
		"Federant" => "Federant",
		"Federo" => "Federo",
		"Felipa" => "Felipa",
		"Fenix" => "Fenix",
		"Finger Paint" => "Finger+Paint",
		"Fjalla One" => "Fjalla+One",
		"Fjord One" => "Fjord+One",
		"Flamenco" => "Flamenco",
		"Flavors" => "Flavors",
		"Fondamento" => "Fondamento",
		"Fontdiner Swanky" => "Fontdiner+Swanky",
		"Forum" => "Forum",
		"Francois One" => "Francois+One",
		"Freckle Face" => "Freckle+Face",
		"Fredericka the Great" => "Fredericka+the+Great",
		"Fredoka One" => "Fredoka+One",
		"Freehand" => "Freehand",
		"Fresca" => "Fresca",
		"Frijole" => "Frijole",
		"Fruktur" => "Fruktur",
		"Fugaz One" => "Fugaz+One",
		"GFS Didot" => "GFS+Didot",
		"GFS Neohellenic" => "GFS+Neohellenic",
		"Gabriela" => "Gabriela",
		"Gafata" => "Gafata",
		"Galdeano" => "Galdeano",
		"Galindo" => "Galindo",
		"Gentium Basic" => "Gentium+Basic",
		"Gentium Book Basic" => "Gentium+Book+Basic",
		"Geo" => "Geo",
		"Geostar" => "Geostar",
		"Geostar Fill" => "Geostar+Fill",
		"Germania One" => "Germania+One",
		"Gilda Display" => "Gilda+Display",
		"Give You Glory" => "Give+You+Glory",
		"Glass Antiqua" => "Glass+Antiqua",
		"Glegoo" => "Glegoo",
		"Gloria Hallelujah" => "Gloria+Hallelujah",
		"Goblin One" => "Goblin+One",
		"Gochi Hand" => "Gochi+Hand",
		"Gorditas" => "Gorditas",
		"Goudy Bookletter 1911" => "Goudy+Bookletter+1911",
		"Graduate" => "Graduate",
		"Grand Hotel" => "Grand+Hotel",
		"Gravitas One" => "Gravitas+One",
		"Great Vibes" => "Great+Vibes",
		"Griffy" => "Griffy",
		"Gruppo" => "Gruppo",
		"Gudea" => "Gudea",
		"Habibi" => "Habibi",
		"Hammersmith One" => "Hammersmith+One",
		"Hanalei" => "Hanalei",
		"Hanalei Fill" => "Hanalei+Fill",
		"Handlee" => "Handlee",
		"Hanuman" => "Hanuman",
		"Happy Monkey" => "Happy+Monkey",
		"Headland One" => "Headland+One",
		"Henny Penny" => "Henny+Penny",
		"Herr Von Muellerhoff" => "Herr+Von+Muellerhoff",
		"Holtwood One SC" => "Holtwood+One+SC",
		"Homemade Apple" => "Homemade+Apple",
		"Homenaje" => "Homenaje",
		"IM Fell DW Pica" => "IM+Fell+DW+Pica",
		"IM Fell DW Pica SC" => "IM+Fell+DW+Pica+SC",
		"IM Fell Double Pica" => "IM+Fell+Double+Pica",
		"IM Fell Double Pica SC" => "IM+Fell+Double+Pica+SC",
		"IM Fell English" => "IM+Fell+English",
		"IM Fell English SC" => "IM+Fell+English+SC",
		"IM Fell French Canon" => "IM+Fell+French+Canon",
		"IM Fell French Canon SC" => "IM+Fell+French+Canon+SC",
		"IM Fell Great Primer" => "IM+Fell+Great+Primer",
		"IM Fell Great Primer SC" => "IM+Fell+Great+Primer+SC",
		"Iceberg" => "Iceberg",
		"Iceland" => "Iceland",
		"Imprima" => "Imprima",
		"Inconsolata" => "Inconsolata",
		"Inder" => "Inder",
		"Indie Flower" => "Indie+Flower",
		"Inika" => "Inika",
		"Irish Grover" => "Irish+Grover",
		"Istok Web" => "Istok+Web",
		"Italiana" => "Italiana",
		"Italianno" => "Italianno",
		"Jacques Francois" => "Jacques+Francois",
		"Jacques Francois Shadow" => "Jacques+Francois+Shadow",
		"Jim Nightshade" => "Jim+Nightshade",
		"Jockey One" => "Jockey+One",
		"Jolly Lodger" => "Jolly+Lodger",
		"Josefin Sans" => "Josefin+Sans",
		"Josefin Slab" => "Josefin+Slab",
		"Joti One" => "Joti+One",
		"Judson" => "Judson",
		"Julee" => "Julee",
		"Julius Sans One" => "Julius+Sans+One",
		"Junge" => "Junge",
		"Jura" => "Jura",
		"Just Another Hand" => "Just+Another+Hand",
		"Just Me Again Down Here" => "Just+Me+Again+Down+Here",
		"Kameron" => "Kameron",
		"Karla" => "Karla",
		"Kaushan Script" => "Kaushan+Script",
		"Kavoon" => "Kavoon",
		"Keania One" => "Keania+One",
		"Kelly Slab" => "Kelly+Slab",
		"Kenia" => "Kenia",
		"Khmer" => "Khmer",
		"Kite One" => "Kite+One",
		"Knewave" => "Knewave",
		"Kotta One" => "Kotta+One",
		"Koulen" => "Koulen",
		"Kranky" => "Kranky",
		"Kreon" => "Kreon",
		"Kristi" => "Kristi",
		"Krona One" => "Krona+One",
		"La Belle Aurore" => "La+Belle+Aurore",
		"Lancelot" => "Lancelot",
		"Lato" => "Lato",
		"League Script" => "League+Script",
		"Leckerli One" => "Leckerli+One",
		"Ledger" => "Ledger",
		"Lekton" => "Lekton",
		"Lemon" => "Lemon",
		"Libre Baskerville" => "Libre+Baskerville",
		"Life Savers" => "Life+Savers",
		"Lilita One" => "Lilita+One",
		"Limelight" => "Limelight",
		"Linden Hill" => "Linden+Hill",
		"Lobster" => "Lobster",
		"Lobster Two" => "Lobster+Two",
		"Londrina Outline" => "Londrina+Outline",
		"Londrina Shadow" => "Londrina+Shadow",
		"Londrina Sketch" => "Londrina+Sketch",
		"Londrina Solid" => "Londrina+Solid",
		"Lora" => "Lora",
		"Love Ya Like A Sister" => "Love+Ya+Like+A+Sister",
		"Loved by the King" => "Loved+by+the+King",
		"Lovers Quarrel" => "Lovers+Quarrel",
		"Luckiest Guy" => "Luckiest+Guy",
		"Lusitana" => "Lusitana",
		"Lustria" => "Lustria",
		"Macondo" => "Macondo",
		"Macondo Swash Caps" => "Macondo+Swash+Caps",
		"Magra" => "Magra",
		"Maiden Orange" => "Maiden+Orange",
		"Mako" => "Mako",
		"Marcellus" => "Marcellus",
		"Marcellus SC" => "Marcellus+SC",
		"Marck Script" => "Marck+Script",
		"Margarine" => "Margarine",
		"Marko One" => "Marko+One",
		"Marmelad" => "Marmelad",
		"Marvel" => "Marvel",
		"Mate" => "Mate",
		"Mate SC" => "Mate+SC",
		"Maven Pro" => "Maven+Pro",
		"McLaren" => "McLaren",
		"Meddon" => "Meddon",
		"MedievalSharp" => "MedievalSharp",
		"Medula One" => "Medula+One",
		"Megrim" => "Megrim",
		"Meie Script" => "Meie+Script",
		"Merienda" => "Merienda",
		"Merienda One" => "Merienda+One",
		"Merriweather" => "Merriweather",
		"Merriweather Sans" => "Merriweather+Sans",
		"Metal" => "Metal",
		"Metal Mania" => "Metal+Mania",
		"Metamorphous" => "Metamorphous",
		"Metrophobic" => "Metrophobic",
		"Michroma" => "Michroma",
		"Milonga" => "Milonga",
		"Miltonian" => "Miltonian",
		"Miltonian Tattoo" => "Miltonian+Tattoo",
		"Miniver" => "Miniver",
		"Miss Fajardose" => "Miss+Fajardose",
		"Modern Antiqua" => "Modern+Antiqua",
		"Molengo" => "Molengo",
		"Molle" => "Molle",
		"Monda" => "Monda",
		"Monofett" => "Monofett",
		"Monoton" => "Monoton",
		"Monsieur La Doulaise" => "Monsieur+La+Doulaise",
		"Montaga" => "Montaga",
		"Montez" => "Montez",
		"Montserrat" => "Montserrat",
		"Montserrat Alternates" => "Montserrat+Alternates",
		"Montserrat Subrayada" => "Montserrat+Subrayada",
		"Moul" => "Moul",
		"Moulpali" => "Moulpali",
		"Mountains of Christmas" => "Mountains+of+Christmas",
		"Mouse Memoirs" => "Mouse+Memoirs",
		"Mr Bedfort" => "Mr+Bedfort",
		"Mr Dafoe" => "Mr+Dafoe",
		"Mr De Haviland" => "Mr+De+Haviland",
		"Mrs Saint Delafield" => "Mrs+Saint+Delafield",
		"Mrs Sheppards" => "Mrs+Sheppards",
		"Muli" => "Muli",
		"Mystery Quest" => "Mystery+Quest",
		"Neucha" => "Neucha",
		"Neuton" => "Neuton",
		"New Rocker" => "New+Rocker",
		"News Cycle" => "News+Cycle",
		"Niconne" => "Niconne",
		"Nixie One" => "Nixie+One",
		"Nobile" => "Nobile",
		"Nokora" => "Nokora",
		"Norican" => "Norican",
		"Nosifer" => "Nosifer",
		"Nothing You Could Do" => "Nothing+You+Could+Do",
		"Noticia Text" => "Noticia+Text",
		"Nova Cut" => "Nova+Cut",
		"Nova Flat" => "Nova+Flat",
		"Nova Mono" => "Nova+Mono",
		"Nova Oval" => "Nova+Oval",
		"Nova Round" => "Nova+Round",
		"Nova Script" => "Nova+Script",
		"Nova Slim" => "Nova+Slim",
		"Nova Square" => "Nova+Square",
		"Numans" => "Numans",
		"Nunito" => "Nunito",
		"Odor Mean Chey" => "Odor+Mean+Chey",
		"Offside" => "Offside",
		"Old Standard TT" => "Old+Standard+TT",
		"Oldenburg" => "Oldenburg",
		"Oleo Script" => "Oleo+Script",
		"Oleo Script Swash Caps" => "Oleo+Script+Swash+Caps",
		"Open Sans" => "Open+Sans",
		"Open Sans Condensed" => "Open+Sans+Condensed",
		"Oranienbaum" => "Oranienbaum",
		"Orbitron" => "Orbitron",
		"Oregano" => "Oregano",
		"Orienta" => "Orienta",
		"Original Surfer" => "Original+Surfer",
		"Oswald" => "Oswald",
		"Over the Rainbow" => "Over+the+Rainbow",
		"Overlock" => "Overlock",
		"Overlock SC" => "Overlock+SC",
		"Ovo" => "Ovo",
		"Oxygen" => "Oxygen",
		"Oxygen Mono" => "Oxygen+Mono",
		"PT Mono" => "PT+Mono",
		"PT Sans" => "PT+Sans",
		"PT Sans Caption" => "PT+Sans+Caption",
		"PT Sans Narrow" => "PT+Sans+Narrow",
		"PT Serif" => "PT+Serif",
		"PT Serif Caption" => "PT+Serif+Caption",
		"Pacifico" => "Pacifico",
		"Paprika" => "Paprika",
		"Parisienne" => "Parisienne",
		"Passero One" => "Passero+One",
		"Passion One" => "Passion+One",
		"Patrick Hand" => "Patrick+Hand",
		"Patrick Hand SC" => "Patrick+Hand+SC",
		"Patua One" => "Patua+One",
		"Paytone One" => "Paytone+One",
		"Peralta" => "Peralta",
		"Permanent Marker" => "Permanent+Marker",
		"Petit Formal Script" => "Petit+Formal+Script",
		"Petrona" => "Petrona",
		"Philosopher" => "Philosopher",
		"Piedra" => "Piedra",
		"Pinyon Script" => "Pinyon+Script",
		"Pirata One" => "Pirata+One",
		"Plaster" => "Plaster",
		"Play" => "Play",
		"Playball" => "Playball",
		"Playfair Display" => "Playfair+Display",
		"Playfair Display SC" => "Playfair+Display+SC",
		"Podkova" => "Podkova",
		"Poiret One" => "Poiret+One",
		"Poller One" => "Poller+One",
		"Poly" => "Poly",
		"Pompiere" => "Pompiere",
		"Pontano Sans" => "Pontano+Sans",
		"Port Lligat Sans" => "Port+Lligat+Sans",
		"Port Lligat Slab" => "Port+Lligat+Slab",
		"Prata" => "Prata",
		"Preahvihear" => "Preahvihear",
		"Press Start 2P" => "Press+Start+2P",
		"Princess Sofia" => "Princess+Sofia",
		"Prociono" => "Prociono",
		"Prosto One" => "Prosto+One",
		"Puritan" => "Puritan",
		"Purple Purse" => "Purple+Purse",
		"Quando" => "Quando",
		"Quantico" => "Quantico",
		"Quattrocento" => "Quattrocento",
		"Quattrocento Sans" => "Quattrocento+Sans",
		"Questrial" => "Questrial",
		"Quicksand" => "Quicksand",
		"Quintessential" => "Quintessential",
		"Qwigley" => "Qwigley",
		"Racing Sans One" => "Racing+Sans+One",
		"Radley" => "Radley",
		"Raleway" => "Raleway",
		"Raleway Dots" => "Raleway+Dots",
		"Rambla" => "Rambla",
		"Rammetto One" => "Rammetto+One",
		"Ranchers" => "Ranchers",
		"Rancho" => "Rancho",
		"Rationale" => "Rationale",
		"Redressed" => "Redressed",
		"Reenie Beanie" => "Reenie+Beanie",
		"Revalia" => "Revalia",
		"Ribeye" => "Ribeye",
		"Ribeye Marrow" => "Ribeye+Marrow",
		"Righteous" => "Righteous",
		"Risque" => "Risque",
		"Roboto:400,300,100" => "Roboto",
		"Roboto+Slab:700,400" => "Roboto+Slab",
		"Roboto Condensed" => "Roboto+Condensed",
		"Rochester" => "Rochester",
		"Rock Salt" => "Rock+Salt",
		"Rokkitt" => "Rokkitt",
		"Romanesco" => "Romanesco",
		"Ropa Sans" => "Ropa+Sans",
		"Rosario" => "Rosario",
		"Rosarivo" => "Rosarivo",
		"Rouge Script" => "Rouge+Script",
		"Ruda" => "Ruda",
		"Rufina" => "Rufina",
		"Ruge Boogie" => "Ruge+Boogie",
		"Ruluko" => "Ruluko",
		"Rum Raisin" => "Rum+Raisin",
		"Ruslan Display" => "Ruslan+Display",
		"Russo One" => "Russo+One",
		"Ruthie" => "Ruthie",
		"Rye" => "Rye",
		"Sacramento" => "Sacramento",
		"Sail" => "Sail",
		"Salsa" => "Salsa",
		"Sanchez" => "Sanchez",
		"Sancreek" => "Sancreek",
		"Sansita One" => "Sansita+One",
		"Sarina" => "Sarina",
		"Satisfy" => "Satisfy",
		"Scada" => "Scada",
		"Schoolbell" => "Schoolbell",
		"Seaweed Script" => "Seaweed+Script",
		"Sevillana" => "Sevillana",
		"Seymour One" => "Seymour+One",
		"Shadows Into Light" => "Shadows+Into+Light",
		"Shadows Into Light Two" => "Shadows+Into+Light+Two",
		"Shanti" => "Shanti",
		"Share" => "Share",
		"Share Tech" => "Share+Tech",
		"Share Tech Mono" => "Share+Tech+Mono",
		"Shojumaru" => "Shojumaru",
		"Short Stack" => "Short+Stack",
		"Siemreap" => "Siemreap",
		"Sigmar One" => "Sigmar+One",
		"Signika" => "Signika",
		"Signika Negative" => "Signika+Negative",
		"Simonetta" => "Simonetta",
		"Sintony" => "Sintony",
		"Sirin Stencil" => "Sirin+Stencil",
		"Six Caps" => "Six+Caps",
		"Skranji" => "Skranji",
		"Slackey" => "Slackey",
		"Smokum" => "Smokum",
		"Smythe" => "Smythe",
		"Sniglet" => "Sniglet",
		"Snippet" => "Snippet",
		"Snowburst One" => "Snowburst+One",
		"Sofadi One" => "Sofadi+One",
		"Sofia" => "Sofia",
		"Sonsie One" => "Sonsie+One",
		"Sorts Mill Goudy" => "Sorts+Mill+Goudy",
		"Source Code Pro" => "Source+Code+Pro",
		"Source Sans Pro" => "Source+Sans+Pro",
		"Special Elite" => "Special+Elite",
		"Spicy Rice" => "Spicy+Rice",
		"Spinnaker" => "Spinnaker",
		"Spirax" => "Spirax",
		"Squada One" => "Squada+One",
		"Stalemate" => "Stalemate",
		"Stalinist One" => "Stalinist+One",
		"Stardos Stencil" => "Stardos+Stencil",
		"Stint Ultra Condensed" => "Stint+Ultra+Condensed",
		"Stint Ultra Expanded" => "Stint+Ultra+Expanded",
		"Stoke" => "Stoke",
		"Strait" => "Strait",
		"Sue Ellen Francisco" => "Sue+Ellen+Francisco",
		"Sunshiney" => "Sunshiney",
		"Supermercado One" => "Supermercado+One",
		"Suwannaphum" => "Suwannaphum",
		"Swanky and Moo Moo" => "Swanky+and+Moo+Moo",
		"Syncopate" => "Syncopate",
		"Tangerine" => "Tangerine",
		"Taprom" => "Taprom",
		"Tauri" => "Tauri",
		"Telex" => "Telex",
		"Tenor Sans" => "Tenor+Sans",
		"Text Me One" => "Text+Me+One",
		"The Girl Next Door" => "The+Girl+Next+Door",
		"Tienne" => "Tienne",
		"Tinos" => "Tinos",
		"Titan One" => "Titan+One",
		"Titillium Web" => "Titillium+Web",
		"Trade Winds" => "Trade+Winds",
		"Trocchi" => "Trocchi",
		"Trochut" => "Trochut",
		"Trykker" => "Trykker",
		"Tulpen One" => "Tulpen+One",
		"Ubuntu" => "Ubuntu",
		"Ubuntu Condensed" => "Ubuntu+Condensed",
		"Ubuntu Mono" => "Ubuntu+Mono",
		"Ultra" => "Ultra",
		"Uncial Antiqua" => "Uncial+Antiqua",
		"Underdog" => "Underdog",
		"Unica One" => "Unica+One",
		"UnifrakturCook" => "UnifrakturCook",
		"UnifrakturMaguntia" => "UnifrakturMaguntia",
		"Unkempt" => "Unkempt",
		"Unlock" => "Unlock",
		"Unna" => "Unna",
		"VT323" => "VT323",
		"Vampiro One" => "Vampiro+One",
		"Varela" => "Varela",
		"Varela Round" => "Varela+Round",
		"Vast Shadow" => "Vast+Shadow",
		"Vibur" => "Vibur",
		"Vidaloka" => "Vidaloka",
		"Viga" => "Viga",
		"Voces" => "Voces",
		"Volkhov" => "Volkhov",
		"Vollkorn" => "Vollkorn",
		"Voltaire" => "Voltaire",
		"Waiting for the Sunrise" => "Waiting+for+the+Sunrise",
		"Wallpoet" => "Wallpoet",
		"Walter Turncoat" => "Walter+Turncoat",
		"Warnes" => "Warnes",
		"Wellfleet" => "Wellfleet",
		"Wendy One" => "Wendy+One",
		"Wire One" => "Wire+One",
		"Yanone Kaffeesatz" => "Yanone+Kaffeesatz",
		"Yellowtail" => "Yellowtail",
		"Yeseva One" => "Yeseva+One",
		"Yesteryear" => "Yesteryear",
		"Zeyada" => "Zeyada",
	);

	return $accelerate_googlefonts;
}
?>
